@@ -3,35 +3,38 @@
  *  Module    : proto.h
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   :
- *  Updated   : 2018-02-13
+ *  Updated   : 2019-07-16
  *  Notes     :
  *
- * Copyright (c) 1997-2019 Urs Janssen <urs@tin.org>
+ * Copyright (c) 1997-2020 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -130,9 +133,9 @@ extern int InitScreen(void);
 extern int RawState(void);
 extern int ReadCh(void);
 extern int get_arrow_key(int prech);
-#if defined(M_UNIX) && !defined(USE_CURSES)
+#if !defined(USE_CURSES)
 	extern int get_termcaps(void);
-#endif /* M_UNIX && !USE_CURSES */
+#endif /* !USE_CURSES */
 extern void EndInverse(void);
 extern void EndWin(void);
 extern void InitWin(void);
@@ -365,7 +368,7 @@ extern t_bool backup_file(const char *filename, const char *backupname);
 extern t_bool copy_fp(FILE *fp_ip, FILE *fp_op);
 extern t_bool invoke_cmd(const char *nam);
 extern t_bool invoke_editor(const char *filename, int lineno, struct t_group *group);
-extern t_bool mail_check(void);
+extern t_bool mail_check(const char *mailbox_name);
 extern void append_file(char *old_filename, char *new_filename);
 extern void asfail(const char *file, int line, const char *cond);
 extern void base_name(const char *fullpath, char *file);
@@ -402,9 +405,6 @@ extern void toggle_inverse_video(void);
 #ifdef HAVE_ISPELL
 	extern t_bool invoke_ispell(const char *nam, struct t_group *group);
 #endif /* HAVE_ISPELL */
-#ifndef M_UNIX
-	extern void make_post_process_cmd(char *cmd, char *dir, char *file);
-#endif /* !M_UNIX */
 #ifndef NO_SHELL_ESCAPE
 	extern void shell_escape(void);
 	extern void do_shell_escape(void);
@@ -434,7 +434,7 @@ extern FILE *get_nntp_fp(FILE *fp);
 /* extern FILE *get_nntp_wr_fp(FILE *fp); */
 extern char *getserverbyfile(const char *file);
 extern int nntp_open(void);
-extern void nntp_close(void);
+extern void nntp_close(t_bool send_no_quit);
 #ifdef NNTP_ABLE
 	extern FILE *nntp_command(const char *, int, char *, size_t);
 	extern char *get_server(char *string, int size);
@@ -656,6 +656,8 @@ extern size_t mystrcat(char **t, const char *s);
 extern void my_strncpy(char *p, const char *q, size_t n);
 extern void parse_format_string(const char *fmtstr, struct t_fmt *fmt);
 extern void str_lwr(char *str);
+extern int my_tolower(int);
+extern int my_toupper(int);
 #if !defined(HAVE_STRCASESTR) || defined(DECL_STRCASESTR)
 	extern char *strcasestr(const char *haystack, const char *needle);
 #endif /* !HAVE_STRCASESTR || DECL_STRCASESTR */
@@ -752,8 +754,8 @@ extern t_bool thread_mark_postprocess(int function, t_function feed_type, int re
 extern void fixup_thread(int respnum, t_bool redraw);
 
 /* version.c */
-extern enum rc_state check_upgrade(char *line, const char *skip, const char *version);
-extern void upgrade_prompt_quit(enum rc_state reason, const char *file);
+extern struct t_version *check_upgrade(char *line, const char *skip, const char *version);
+extern void upgrade_prompt_quit(struct t_version *upgrade, const char *file);
 
 /* wildmat.c */
 extern t_bool wildmat(const char *text, char *p, t_bool icase);
