@@ -3,35 +3,38 @@
  *  Module    : tnntp.h
  *  Author    : Thomas Dickey <dickey@invisible-island.net>
  *  Created   : 1997-03-05
- *  Updated   : 2006-02-15
+ *  Updated   : 2019-02-18
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2019 Thomas Dickey <dickey@invisible-island.net>
+ * Copyright (c) 1997-2020 Thomas Dickey <dickey@invisible-island.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -42,21 +45,8 @@
 #define s_flush	fflush
 #define s_fclose	fclose
 #define s_gets	fgets
-#if 0 /* __BEOS__ port in progress */
-#	ifdef HAVE_CLOSESOCKET
-#		define s_close	closesocket
-#	else
-#		define s_close	close
-#	endif /* HAVE_CLOSESOCKET */
-#	ifdef __BEOS__
-#		define s_puts(s,fd)	write(fileno(fd),s,strlen(s))
-#	else
-#		define s_puts	fputs
-#	endif /* __BEOS__ */
-#else
-#	define s_close	close
-#	define s_puts	fputs
-#endif /* 0 */
+#define s_close	close
+#define s_puts	fputs
 #define s_dup	dup
 #define s_end()
 
@@ -73,17 +63,13 @@
 #		ifdef HAVE_STROPTS_H
 #			include	<stropts.h>
 #		endif /* HAVE_STROPTS_H */
-#		ifdef HAVE_NET_SOCKET_H /* __BEOS__ fd_* macros */
-#			include <net/socket.h>
+#		ifdef HAVE_SYS_SOCKET_H
+#			include	<sys/socket.h>
 #		else
-#			ifdef HAVE_SYS_SOCKET_H
-#				include	<sys/socket.h>
-#			else
-#				ifdef HAVE_SOCKET_H
-#					include <socket.h>
-#				endif /* HAVE_SOCKET_H */
-#			endif /* HAVE_SYS_SOCKET_H */
-#		endif /* HAVE_NET_SOCKET_H */
+#			ifdef HAVE_SOCKET_H
+#				include <socket.h>
+#			endif /* HAVE_SOCKET_H */
+#		endif /* HAVE_SYS_SOCKET_H */
 #		ifdef HAVE_NETINET_IN_H
 #			include	<netinet/in.h>
 #		endif /* HAVE_NETINET_IN_H */
