@@ -3,35 +3,38 @@
  *  Module    : active.c
  *  Author    : I. Lea
  *  Created   : 1992-02-16
- *  Updated   : 2016-10-10
+ *  Updated   : 2019-01-28
  *  Notes     :
  *
- * Copyright (c) 1992-2018 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1992-2020 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -92,7 +95,7 @@ need_reread_active_file(
 
 /*
  * Resync active file when reread_active_file_secs have passed or
- * force_reread_actve_file is set.
+ * force_reread_active_file is set.
  * Return TRUE if a reread was performed
  */
 t_bool
@@ -199,6 +202,12 @@ process_bogus(
 
 	active_add(ptr, T_ARTNUM_CONST(0), T_ARTNUM_CONST(1), T_ARTNUM_CONST(0), "n");
 	ptr->bogus = TRUE;		/* Mark it bogus */
+	/*
+	 * Set pointer to default attributes
+	 */
+	if (ptr->attribute && !ptr->attribute->global)
+		free(ptr->attribute);
+	ptr->attribute = scopes[0].attribute;
 
 	if (my_group_add(name, FALSE) < 0)
 		return TRUE;
@@ -234,10 +243,10 @@ parse_active_line(
 
 	if (!p || !q || !r || !lineok) {
 #ifdef DEBUG
-		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", txt_bad_active_file, line);
+		/* TODO: This also logs broken non NNTP active lines (i.e. mail.active) to NNTP */
+		if (debug & DEBUG_NNTP && verbose > 1)
+			debug_print_file("NNTP", "Active file corrupt - %s", line);
 #endif /* DEBUG */
-		error_message(2, _(txt_bad_active_file), line);
 		return FALSE;
 	}
 
@@ -281,10 +290,9 @@ parse_count_line(
 
 	if (!p || !q || !r || !s || !lineok) {
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", _(txt_unparseable_counts), line);
+		if (debug & DEBUG_NNTP && verbose > 1)
+			debug_print_file("NNTP", "unparsable \"LIST COUNTS\" line: \"%s\"", line);
 #	endif /* DEBUG */
-		error_message(2, _(txt_unparseable_counts), line);
 		return FALSE;
 	}
 
@@ -306,7 +314,7 @@ parse_count_line(
  * We can't know the 'moderator' status and always return 'y'
  * But we don't change if the 'moderator' status is already checked by
  * read_active_file()
- * Returnes TRUE if NNTP is enabled and authentication is needed
+ * Returns TRUE if NNTP is enabled and authentication is needed
  */
 #ifdef NNTP_ABLE
 static t_bool
@@ -331,7 +339,6 @@ do_read_newsrc_active_file(
 	int index_o = 0;
 #endif /* NNTP_ABLE */
 
-
 	rewind(fp);
 
 	if (!batch_mode || verbose)
@@ -363,7 +370,7 @@ do_read_newsrc_active_file(
 				ngnames[index_i] = my_strdup(ptr);
 				snprintf(buf, sizeof(buf), "GROUP %s", ngnames[index_i]);
 #	ifdef DEBUG
-				if (debug & DEBUG_NNTP)
+				if ((debug & DEBUG_NNTP) && verbose > 1)
 					debug_print_file("NNTP", "read_newsrc_active_file() %s", buf);
 #	endif /* DEBUG */
 				put_server(buf);
@@ -385,7 +392,7 @@ do_read_newsrc_active_file(
 					for (i = 0; i < window - 1; i++) {
 						snprintf(buf, sizeof(buf), "GROUP %s", ngnames[j]);
 #	ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "read_newsrc_active_file() %s", buf);
 #	endif /* DEBUG */
 						put_server(buf);
@@ -407,16 +414,14 @@ do_read_newsrc_active_file(
 
 							snprintf(fmt, sizeof(fmt), "%%"T_ARTNUM_SFMT" %%"T_ARTNUM_SFMT" %%"T_ARTNUM_SFMT" %%%ds", NNTP_GRPLEN);
 							if (sscanf(line, fmt, &count, &min, &max, ngname) != 4) {
-								error_message(2, _(txt_error_invalid_response_to_group), line);
 #	ifdef DEBUG
-								if (debug & DEBUG_NNTP) /* TODO: -> lang.c */
+								if (debug & DEBUG_NNTP && verbose > 1)
 									debug_print_file("NNTP", "Invalid response to \"GROUP %s\": \"%s\"", ngnames[index_o], line);
 #	endif /* DEBUG */
 							}
 							if (strcmp(ngname, ngnames[index_o]) != 0) {
-								error_message(2, _(txt_error_wrong_newsgroupname_in_group_response), ngname, ngnames[index_o], line);
 #	ifdef DEBUG
-								if (debug & DEBUG_NNTP) /* TODO: -> lang.c */
+								if (debug & DEBUG_NNTP && verbose > 1)
 									debug_print_file("NNTP", "Groupname mismatch in response to \"GROUP %s\": \"%s\"", ngnames[index_o], line);
 #	endif /* DEBUG */
 							}
@@ -446,7 +451,7 @@ do_read_newsrc_active_file(
 
 					default:
 #	ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "NOT_OK %s", line);
 #	endif /* DEBUG */
 						free(ngnames[index_o]);
@@ -610,7 +615,7 @@ read_active_file(
 
 	while ((ptr = tin_fgets(fp, FALSE)) != NULL) {
 #if defined(DEBUG) && defined(NNTP_ABLE)
-		if (debug & DEBUG_NNTP)
+		if ((debug & DEBUG_NNTP) && verbose) /* long multiline response */
 			debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #endif /* DEBUG && NNTP_ABLE */
 
@@ -688,7 +693,7 @@ read_active_counts(
 
 	while ((ptr = tin_fgets(fp, FALSE)) != NULL) {
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
+		if ((debug & DEBUG_NNTP) && verbose) /* long multiline response */
 			debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 
@@ -749,9 +754,9 @@ read_news_active_file(
 	FILE *fp;
 	int newgrps = 0;
 	t_bool do_group_cmds = !nntp_caps.list_counts;
-#ifdef NNTP_ABLE
+#if defined(NNTP_ABLE) && !defined(DISABLE_PIPELINING)
 	t_bool did_list_cmd = FALSE;
-#endif /* NNTP_ABLE */
+#endif /* NNTP_ABLE && !DISABLE_PIPELINING */
 
 	/*
 	 * Ignore -n if no .newsrc can be found or .newsrc is empty
@@ -772,7 +777,9 @@ read_news_active_file(
 	/* Read an active file if it is allowed */
 	if (list_active) {
 #ifdef NNTP_ABLE
+#	ifndef DISABLE_PIPELINING
 		did_list_cmd = TRUE;
+#	endif /* !DISABLE_PIPELINING */
 		if (read_news_via_nntp && nntp_caps.list_counts)
 			read_active_counts();
 		else
@@ -785,7 +792,7 @@ read_news_active_file(
 #ifdef NNTP_ABLE
 #	ifndef DISABLE_PIPELINING
 		/*
-		 * prefer LIST COUNTS, otherwise use LIST ACIVE (-l) or GROUP (-n)
+		 * prefer LIST COUNTS, otherwise use LIST ACTIVE (-l) or GROUP (-n)
 		 * or both (-ln); LIST COUNTS/ACTIVE grplist is used up to
 		 * PIPELINE_LIMIT groups in newsrc
 		 */
@@ -800,7 +807,7 @@ read_news_active_file(
 			t_bool need_auth = FALSE;
 
 			*buff = '\0';
-			/* we can't use for_each_group(i) yet, so we have to prase the newsrc */
+			/* we can't use for_each_group(i) yet, so we have to parse the newsrc */
 			if ((fp = fopen(newsrc, "r")) != NULL) {
 				while (tin_fgets(fp, FALSE) != NULL)
 					j++;
@@ -851,7 +858,7 @@ read_news_active_file(
 						} else {
 							while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
 #		ifdef DEBUG
-								if (debug & DEBUG_NNTP)
+								if ((debug & DEBUG_NNTP) && verbose) /* long multiline response */
 									debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #		endif /* DEBUG */
 								if (nntp_caps.type == CAPABILITIES && nntp_caps.list_counts) {
@@ -904,7 +911,7 @@ read_news_active_file(
 		newgrps = check_for_any_new_groups();
 
 	/*
-	 * finally we have a list of all groups an can set the attributes
+	 * finally we have a list of all groups and can set the attributes
 	 */
 	assign_attributes_to_groups();
 
@@ -987,7 +994,7 @@ check_for_any_new_groups(
 	}
 
 #ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "Newnews old=[%lu]  new=[%lu]", (unsigned long int) old_newnews_time, (unsigned long int) new_newnews_time);
 #endif /* DEBUG */
 
@@ -1088,7 +1095,7 @@ subscribe_new_group(
 		/*
 		 * as subscribe_new_group() is called from check_for_any_new_groups()
 		 * which has pending data on the socket if reading via NNTP we are not
-		 * allowed to issue any NNTP comands yet
+		 * allowed to issue any NNTP commands yet
 		 */
 		subscribe(&active[my_group[idx]], SUBSCRIBED, bool_not(read_news_via_nntp));
 		/*
@@ -1128,7 +1135,7 @@ match_group_list(
 		separator = strchr(group_list, ',');
 		group_len = MIN(((separator == NULL) ? list_len : (size_t) (separator - group_list)), sizeof(pattern) - 1);
 
-		if ((negate = ('!' == *group_list))) {
+		if ((negate = (*group_list == '!'))) {
 			/*
 			 * a '!' before the pattern inverts sense of match
 			 */
@@ -1150,7 +1157,7 @@ match_group_list(
 		/*
 		 * now examine next entry if any
 		 */
-		if ((char) 0 != group_list[group_len])
+		if (group_list[group_len] != '\0')
 			group_len++;	/* skip the separator */
 
 		group_list += group_len;
@@ -1209,7 +1216,7 @@ load_newnews_info(
 	newnews[i].time = new_time;
 
 #ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "ACTIVE host=[%s] time=[%lu]", newnews[i].host, (unsigned long int) newnews[i].time);
 #endif /* DEBUG */
 }
@@ -1323,7 +1330,7 @@ make_group_list(
 				make_group_list(active_file, base_dir, fixed_base, group_path);
 				find_art_max_min(group_path, &art_max, &art_min);
 				append_group_line(active_file, group_path + strlen(fixed_base) + 1, art_max, art_min, fixed_base);
-				if ((ptr = strrchr(group_path, '/')) != NULL) /* TODO: Unix'ism */
+				if ((ptr = strrchr(group_path, '/')) != NULL)
 					*ptr = '\0';
 			}
 		}
