@@ -1399,7 +1399,7 @@ parse_headers(
 			break;
 
 		unfold_header(ptr);
-		switch (toupper((unsigned char) *ptr)) {
+		switch (my_toupper((unsigned char) *ptr)) {
 			case 'A':	/* Archive-name:  optional */
 				/*
 				 * Archive-name: {name}/{part|patch}{number}
@@ -1792,10 +1792,10 @@ get_path_header(
 		nntp_caps.xpat = FALSE;
 	/* as nntp_caps.hdr may work with other headers we don't disable it*/
 
-#ifdef DEBUG
+#	ifdef DEBUG
 	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "%s: Neither \"[X]HDR Path\" nor \"XPAT Path\" are supportet.", group->name);
-#endif /* DEBUG */
+#	endif /* DEBUG */
 	return supported;
 }
 #endif /* NNTP_ABLE */
