@@ -3,35 +3,38 @@
  *  Module    : config.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2018-11-22
+ *  Updated   : 2019-07-03
  *  Notes     : Configuration file routines
  *
- * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -53,7 +56,7 @@
  */
 static t_bool match_item(char *line, const char *pat, char *dst, size_t dstlen);
 static t_bool rc_update(FILE *fp);
-static t_bool rc_post_update(FILE *fp);
+static t_bool rc_post_update(FILE *fp/* , struct t_version *upgrade */);
 static void write_server_config(void);
 #ifdef HAVE_COLOR
 	static t_bool match_color(char *line, const char *pat, int *dst, int max);
@@ -74,7 +77,7 @@ read_config_file(
 {
 	FILE *fp;
 	char buf[LEN], tmp[LEN];
-	enum rc_state upgrade = RC_CHECK;
+	struct t_version *upgrade = NULL;
 #ifdef CHARSET_CONVERSION
 	int i;
 	t_bool is_7bit;
@@ -90,17 +93,17 @@ read_config_file(
 		if (buf[0] == '\n')
 			continue;
 		if (buf[0] == '#') {
-			if (upgrade == RC_CHECK && !global_file && match_string(buf, "# tin configuration file V", NULL, 0)) {
+			if (upgrade == NULL && !global_file && match_string(buf, "# tin configuration file V", NULL, 0)) {
 				upgrade = check_upgrade(buf, "# tin configuration file V", TINRC_VERSION);
-				if (upgrade != RC_IGNORE)
+				if (upgrade->state != RC_IGNORE)
 					upgrade_prompt_quit(upgrade, CONFIG_FILE);
-				if (upgrade == RC_UPGRADE)
+				if (upgrade->state == RC_UPGRADE)
 					rc_update(fp);
 			}
 			continue;
 		}
 
-		switch (tolower((unsigned char) buf[0])) {
+		switch (my_tolower((unsigned char) buf[0])) {
 		case 'a':
 			if (match_boolean(buf, "abbreviate_groupname=", &tinrc.abbreviate_groupname))
 				break;
@@ -228,10 +231,8 @@ read_config_file(
 			if (match_color(buf, "col_quote3=", &tinrc.col_quote3, MAX_COLOR))
 				break;
 
-#ifdef HAVE_COLOR
 			if (match_color(buf, "col_extquote=", &tinrc.col_extquote, MAX_COLOR))
 				break;
-#endif /* HAVE_COLOR */
 
 			if (match_color(buf, "col_head=", &tinrc.col_head, MAX_COLOR))
 				break;
@@ -275,8 +276,14 @@ read_config_file(
 			if (match_color(buf, "col_markstroke=", &tinrc.col_markstroke, MAX_COLOR))
 				break;
 #endif /* HAVE_COLOR */
-			if (match_list(buf, "confirm_choice=", txt_confirm_choices, &tinrc.confirm_choice))
-				break;
+
+			if (upgrade && upgrade->file_version < 10316) {
+				if (match_list(buf, "confirm_choice=", txt_confirm_choices, &tinrc.confirm_choice))
+					break;
+			} else {
+				if (match_integer(buf, "confirm_choice=", &tinrc.confirm_choice, TINRC_CONFIRM_MAX))
+					break;
+			}
 
 			break;
 
@@ -531,13 +538,8 @@ read_config_file(
 #endif /* HAVE_ALARM && SIGALRM */
 
 #ifdef HAVE_UNICODE_NORMALIZATION
-#	if (HAVE_UNICODE_NORMALIZATION >= 2)
-			if (match_integer(buf, "normalization_form=", &tinrc.normalization_form, NORMALIZE_NFD))
+			if (match_integer(buf, "normalization_form=", &tinrc.normalization_form, NORMALIZE_MAX))
 				break;
-#	else
-			if (match_integer(buf, "normalization_form=", &tinrc.normalization_form, NORMALIZE_NFKC))
-				break;
-#	endif /* HAVE_UNICODE_NORMALIZATION >= 2 */
 #endif /* HAVE_UNICODE_NORMALIZATION */
 
 			break;
@@ -579,6 +581,16 @@ read_config_file(
 
 		case 'q':
 			if (match_string(buf, "quote_chars=", tinrc.quote_chars, sizeof(tinrc.quote_chars))) {
+				if (upgrade && upgrade->file_version < 10317) { /* %s/%S changed to %I */
+					char *q = tinrc.quote_chars;
+
+					while (*q) {
+						if (*q == '%' && (*(q + 1) == 's' || *(q + 1) == 'S'))
+							*(++q) = 'I';
+
+						q++;
+					}
+				}
 				quote_dash_to_space(tinrc.quote_chars);
 				break;
 			}
@@ -833,8 +845,10 @@ read_config_file(
 			break;
 		}
 	}
-	if (upgrade == RC_UPGRADE)
-		rc_post_update(fp);
+	if (!global_file && upgrade && upgrade->state == RC_UPGRADE)
+		rc_post_update(fp/* , upgrade */);
+
+	FreeAndNull(upgrade);
 	fclose(fp);
 
 	/*
@@ -858,10 +872,7 @@ read_config_file(
 		}
 	}
 	if (is_7bit) {
-		if (tinrc.mail_mime_encoding != MIME_ENCODING_7BIT)
-			tinrc.mail_mime_encoding = MIME_ENCODING_7BIT;
-		if (tinrc.post_mime_encoding != MIME_ENCODING_7BIT)
-			tinrc.post_mime_encoding = MIME_ENCODING_7BIT;
+		tinrc.mail_mime_encoding = tinrc.post_mime_encoding = MIME_ENCODING_7BIT;
 	} else {
 		if (tinrc.mail_mime_encoding == MIME_ENCODING_7BIT)
 			tinrc.mail_mime_encoding = MIME_ENCODING_QP;
@@ -944,7 +955,7 @@ write_config_file(
 	fprintf(fp, "prompt_followupto=%s\n\n", print_boolean(tinrc.prompt_followupto));
 
 	fprintf(fp, "%s", _(txt_confirm_choice.tinrc));
-	fprintf(fp, "confirm_choice=%s\n\n", txt_confirm_choices[tinrc.confirm_choice]);
+	fprintf(fp, "confirm_choice=%d\n\n", tinrc.confirm_choice);
 
 	fprintf(fp, "%s", _(txt_mark_ignore_tags.tinrc));
 	fprintf(fp, "mark_ignore_tags=%s\n\n", print_boolean(tinrc.mark_ignore_tags));
@@ -1276,10 +1287,8 @@ write_config_file(
 	fprintf(fp, "%s", _(txt_col_subject.tinrc));
 	fprintf(fp, "col_subject=%d\n\n", tinrc.col_subject);
 
-#ifdef HAVE_COLOR
 	fprintf(fp, "%s", _(txt_col_extquote.tinrc));
 	fprintf(fp, "col_extquote=%d\n\n", tinrc.col_extquote);
-#endif /* HAVE_COLOR */
 
 	fprintf(fp, "%s", _(txt_col_response.tinrc));
 	fprintf(fp, "col_response=%d\n\n", tinrc.col_response);
@@ -1809,7 +1818,7 @@ rc_update(
 		if (buf[0] == '#' || buf[0] == '\n')
 			continue;
 
-		switch (tolower((unsigned char) buf[0])) {
+		switch (my_tolower((unsigned char) buf[0])) {
 			case 'a':
 				if (match_boolean(buf, "auto_bcc=", &auto_bcc))
 					break;
@@ -1861,7 +1870,9 @@ rc_update(
 				 *    commands, now we look for %G
 				 */
 				if (match_string(buf, "default_sigfile=", tinrc.sigfile, sizeof(tinrc.sigfile))) {
-					if (tinrc.sigfile[0] == '!') {
+					size_t l = strlen(tinrc.sigfile);
+
+					if (tinrc.sigfile[0] == '!' && (tinrc.sigfile[l - 2] != '%' || tinrc.sigfile[l - 1] != 'G')) {
 						char *newbuf = my_malloc(sizeof(tinrc.sigfile) + 4);
 
 						sprintf(newbuf, "%s %s", tinrc.sigfile, "%G");
@@ -2014,10 +2025,14 @@ rc_update(
  * auto update tinrc
  * called at the end of read_config_file()
  * useful to update variables which are already present in tinrc
+ *
+ * pass upgrade to this function once we need to exactly check
+ * upgrade->file_version, upgrade->current_version
  */
 static t_bool
 rc_post_update(
-	FILE *fp)
+	FILE *fp
+	/* , struct t_version *upgrade */)
 {
 	char buf[LEN];
 	int groupname_max_length = 0;
@@ -2030,7 +2045,7 @@ rc_post_update(
 		if (buf[0] == '#' || buf[0] == '\n')
 			continue;
 
-		switch (tolower((unsigned char) buf[0])) {
+		switch (my_tolower((unsigned char) buf[0])) {
 			case 'c':
 #ifdef USE_CANLOCK
 				{
@@ -2056,7 +2071,9 @@ rc_post_update(
 				 * commands, now we look for %G
 				 */
 				if (match_string(buf, "sigfile=", tinrc.sigfile, sizeof(tinrc.sigfile))) {
-					if (tinrc.sigfile[0] == '!') {
+					size_t l = strlen(tinrc.sigfile);
+
+					if (tinrc.sigfile[0] == '!'&& (tinrc.sigfile[l - 2] != '%' || tinrc.sigfile[l - 1] != 'G')) {
 						char *newbuf = my_malloc(sizeof(tinrc.sigfile) + 4);
 
 						sprintf(newbuf, "%s %s", tinrc.sigfile, "%G");
@@ -2108,7 +2125,7 @@ read_server_config(
 	char file[PATH_LEN];
 	char newnews_info[LEN];
 	char serverdir[PATH_LEN];
-	enum rc_state upgrade = RC_CHECK;
+	struct t_version *upgrade = NULL;
 
 #ifdef NNTP_ABLE
 	if (read_news_via_nntp && !read_saved_news && nntp_tcp_port != IPPORT_NNTP)
@@ -2121,8 +2138,10 @@ read_server_config(
 	joinpath(serverdir, sizeof(serverdir), rcdir, file);
 	joinpath(file, sizeof(file), serverdir, SERVERCONFIG_FILE);
 	joinpath(local_newsgroups_file, sizeof(local_newsgroups_file), serverdir, NEWSGROUPS_FILE);
+
 	if ((fp = fopen(file, "r")) == NULL)
 		return;
+
 	while ((line = tin_fgets(fp, FALSE)) != NULL) {
 		if ((*line == '#') || (*line == '\0'))
 			continue;
@@ -2136,10 +2155,13 @@ read_server_config(
 			free(tmp_info);
 			continue;
 		}
+
 		if (match_string(line, "version=", NULL, 0)) {
-			if (upgrade != RC_CHECK) /* ignore duplicate version lines; last match counts */
+			if (upgrade != NULL) /* ignore duplicate version lines; first match counts */
 				continue;
-			if ((upgrade = check_upgrade(line, "version=", SERVERCONFIG_VERSION)) == RC_IGNORE) /* Expected version number; nothing to do -> continue */
+
+			upgrade = check_upgrade(line, "version=", SERVERCONFIG_VERSION);
+			if (upgrade->state == RC_IGNORE) /* Expected version number; nothing to do -> continue */
 				continue;
 
 			/* Nothing to do yet for RC_UPGRADE and RC_DOWNGRADE */
@@ -2147,6 +2169,7 @@ read_server_config(
 		}
 	}
 	fclose(fp);
+	FreeAndNull(upgrade);
 }
 
 
@@ -2197,9 +2220,10 @@ write_server_config(
 	fprintf(fp, _(txt_serverconfig_header), PRODUCT, tin_progname, VERSION, RELEASEDATE, RELEASENAME, PRODUCT, PRODUCT);
 	fprintf(fp, "version=%s\n", SERVERCONFIG_VERSION);
 
-	if ((i = find_newnews_index(nntp_server)) >= 0)
+	if ((i = find_newnews_index(nntp_server)) >= 0) {
 		if (my_strftime(timestring, sizeof(timestring) - 1, "%Y-%m-%d %H:%M:%S UTC", gmtime(&(newnews[i].time))))
 			fprintf(fp, "last_newnews=%lu (%s)\n", (unsigned long int) newnews[i].time, timestring);
+	}
 
 	fchmod(fileno(fp), (mode_t) (S_IRUSR|S_IWUSR)); /* rename_file() preserves mode */
 
