@@ -3,35 +3,38 @@
  *  Module    : mail.c
  *  Author    : I. Lea
  *  Created   : 1992-10-02
- *  Updated   : 2016-07-29
+ *  Updated   : 2018-02-15
  *  Notes     : Mail handling routines for creating pseudo newsgroups
  *
- * Copyright (c) 1992-2018 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1992-2020 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -90,7 +93,7 @@ read_mail_active_file(
 	void)
 {
 	FILE *fp;
-	char buf[LEN];
+	char *buf;
 	char my_spooldir[PATH_LEN];
 	char buf2[PATH_LEN];
 	t_artnum min, max;
@@ -115,7 +118,7 @@ read_mail_active_file(
 		return;
 	}
 
-	while (fgets(buf, (int) sizeof(buf), fp) != NULL) {
+	while ((buf = tin_fgets(fp, FALSE))) {
 		if (!parse_active_line(buf, &max, &min, my_spooldir) || *buf == '\0')
 			continue;
 
@@ -212,10 +215,10 @@ write_mail_active_file(
 				fclose(fp);
 			}
 			i = rename(file_tmp, mail_active_file);
-#ifdef DEBUG
+#	ifdef DEBUG
 			if ((debug & DEBUG_MISC) && i) /* TODO: is this the right debug-level? */
 				perror_message(_(txt_rename_error), file_tmp, mail_active_file);
-#endif /* DEBUG */
+#	endif /* DEBUG */
 		} else
 			unlink(file_tmp);
 	}
@@ -276,9 +279,10 @@ open_newsgroups_fp(
 				struct stat buf;
 
 #	ifdef DEBUG
-					if (debug & DEBUG_NNTP)
-						debug_print_file("NNTP", "open_newsgroups_fp Using local copy of newsgroups file");
+				if ((debug & DEBUG_NNTP) && verbose > 1)
+					debug_print_file("NNTP", "open_newsgroups_fp Using local copy of newsgroups file");
 #	endif /* DEBUG */
+
 				if (!fstat(fileno(result), &buf)) {
 					if (buf.st_size > 0)
 						return result;
@@ -338,7 +342,7 @@ open_newsgroups_fp(
 							}
 							while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
 #			ifdef DEBUG
-								if (debug & DEBUG_NNTP)
+								if (debug & DEBUG_NNTP && verbose)
 									debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #			endif /* DEBUG */
 								fprintf(result, "%s\n", str_trim(ptr));
@@ -364,7 +368,7 @@ open_newsgroups_fp(
 					}
 					while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
 #			ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if (debug & DEBUG_NNTP && verbose)
 							debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #			endif /* DEBUG */
 						fprintf(result, "%s\n", str_trim(ptr));
@@ -384,7 +388,7 @@ open_newsgroups_fp(
 			if (result != NULL) {
 				if (!no_more_wildmat)
 					return result;
-				else /* AUTH request while pipeling or some error */
+				else /* AUTH request while pipelining or some error */
 					fclose(result);
 			}
 		}
@@ -462,6 +466,10 @@ read_groups_descriptions(
 	struct t_group *group;
 
 	while ((ptr = tin_fgets(fp, FALSE)) != NULL) {
+#ifdef DEBUG
+		if ((debug & DEBUG_NNTP) && fp == FAKE_NNTP_FP && verbose)
+			debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
+#endif /* DEBUG */
 		if (*ptr == '#' || *ptr == '\0')
 			continue;
 
