@@ -3,35 +3,38 @@
  *  Module    : main.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2017-02-22
+ *  Updated   : 2019-07-16
  *  Notes     :
  *
- * Copyright (c) 1991-2018 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -145,6 +148,15 @@ main(
 	init_selfinfo();
 	init_group_hash();
 
+	/*
+	 * Set cCOLS temporarily to trim (localized) messages
+	 * It does not matter if this value is greater than the actual
+	 * terminal size
+	 *
+	 * cCOLS will be set later to the real terminal width
+	 */
+	cCOLS = 80;
+
 	/*
 	 * Process envargs & command line options
 	 * These override the configured in values
@@ -168,15 +180,13 @@ main(
 	no_write = TRUE;		/* don't allow any writing back during startup */
 
 	if (!batch_mode) {
-#ifdef M_UNIX
-#	ifndef USE_CURSES
+#ifndef USE_CURSES
 		if (!get_termcaps()) {
 			error_message(2, _(txt_screen_init_failed), tin_progname);
 			free_all_arrays();
 			giveup();
 		}
-#	endif /* !USE_CURSES */
-#endif /* M_UNIX */
+#endif /* !USE_CURSES */
 
 		/*
 		 * Init curses emulation
@@ -204,7 +214,7 @@ main(
 	if (!nntp_server || !*nntp_server)
 		nntp_server = getserverbyfile(NNTP_SERVER_FILE);
 	if (read_news_via_nntp && !read_saved_news && nntp_open()) {
-		nntp_close();
+		nntp_close(FALSE);
 		free_all_arrays();
 		giveup();
 	}
@@ -311,7 +321,7 @@ main(
 		tin_done(EXIT_SUCCESS, NULL);
 	}
 
-	/* TODO: replace hardcoded key-name in txt_info_postponed */
+	/* TODO: replace hard coded key-name in txt_info_postponed */
 	if ((count = count_postponed_articles()))
 		wait_message(3, _(txt_info_postponed), count, PLURAL(count, txt_article));
 
@@ -375,7 +385,7 @@ main(
 	 * or
 	 * Save any new articles to savedir structure for later reading
 	 *
-	 * TODO: should we temporarely set
+	 * TODO: should we temporarily set
 	 *       getart_limit=-1,thread_articles=0,sort_article_type=0
 	 *       for speed reasons?
 	 */
@@ -431,7 +441,11 @@ main(
  * process command line options
  * [01235789beEFijJkKLOtTyY] are unused
  * [W] is reserved
- * [BCPU] have been in use at some time, but now are unused
+ * [BCPU] have been in use at some time, but now are unused:
+ *   B BBS mode (M_AMIGA only)
+ *   C count articles
+ *   P purge group index files of articles that no longer exist
+ *   U update index files in background
  */
 #define OPTIONS "46aAcdD:f:g:G:hHI:lm:M:nNop:qQrRs:SuvVwxXzZ"
 
@@ -518,7 +532,7 @@ read_cmd_line_options(
 
 			case 'D':		/* debug mode */
 #ifdef DEBUG
-				debug = atoi(optarg);
+				debug = atoi(optarg) & 0xff;
 				debug_delete_files();
 #else
 				error_message(2, _(txt_option_not_enabled), "-DDEBUG");
@@ -665,8 +679,8 @@ read_cmd_line_options(
 				update_index = TRUE;
 				break;
 
-			case 'v':	/* verbose mode */
-				verbose = TRUE;
+			case 'v':	/* verbose mode, can be used multiple times */
+				verbose++;
 				break;
 
 			case 'V':
@@ -733,9 +747,9 @@ read_cmd_line_options(
 			get_newsrcname(newsrc, sizeof(newsrc), uts.nodename);
 #else
 			char nodenamebuf[256]; /* SUSv2 limit; better use HOST_NAME_MAX */
-#ifdef HAVE_GETHOSTNAME
+#	ifdef HAVE_GETHOSTNAME
 			(void) gethostname(nodenamebuf, sizeof(nodenamebuf));
-#endif /* HAVE_GETHOSTNAME */
+#	endif /* HAVE_GETHOSTNAME */
 			get_newsrcname(newsrc, sizeof(newsrc), nodenamebuf);
 #endif /* HAVE_SYS_UTSNAME_H && HAVE_UNAME */
 		}
@@ -745,10 +759,6 @@ read_cmd_line_options(
 	 * Sort out option conflicts
 	 */
 	if (!batch_mode) {
-		if (verbose) {
-			wait_message(2, _(txt_useful_with_batch_mode), "-v");
-			verbose = FALSE;
-		}
 		if (catchup) {
 			wait_message(2, _(txt_useful_with_batch_mode), "-c");
 			catchup = FALSE;
@@ -759,6 +769,12 @@ read_cmd_line_options(
 			read_saved_news = FALSE;
 		}
 	}
+	if (!(batch_mode || debug)) {
+		if (verbose) {
+			wait_message(2, _(txt_useful_with_batch_or_debug_mode), "-v");
+			verbose = FALSE;
+		}
+	}
 	if (post_postponed_and_exit && force_no_post) {
 		wait_message(2, _(txt_useless_combination), "-o", "-x", "-x");
 		force_no_post = FALSE;
@@ -853,15 +869,15 @@ usage(
 	error_message(2, _(txt_usage_tin), theProgname);
 
 #if defined(NNTP_ABLE) && defined(INET6)
-		error_message(2, _(txt_usage_force_ipv4));
-		error_message(2, _(txt_usage_force_ipv6));
+	error_message(2, _(txt_usage_force_ipv4));
+	error_message(2, _(txt_usage_force_ipv6));
 #endif /* NNTP_ABLE && INET6 */
 
 #ifdef HAVE_COLOR
-		error_message(2, _(txt_usage_toggle_color));
+	error_message(2, _(txt_usage_toggle_color));
 #endif /* HAVE_COLOR */
 #ifdef NNTP_ABLE
-		error_message(2, _(txt_usage_force_authentication));
+	error_message(2, _(txt_usage_force_authentication));
 #endif /* NNTP_ABLE */
 
 	error_message(2, _(txt_usage_catchup));
