@@ -3,7 +3,7 @@
  *  Module    : mimetypes.c
  *  Author    : J. Faultless
  *  Created   : 2000-03-31
- *  Updated   : 2017-03-28
+ *  Updated   : 2019-02-18
  *  Notes     : mime.types handling
  *
  * Copyright (c) 2000-2019 Jason Faultless <jason@altarstone.com>
@@ -109,10 +109,8 @@ lookup_mimetype(
 	if (_lookup_mimetype(buf, ext, part))
 		return;
 
-#ifdef M_UNIX
 	if (_lookup_mimetype("/etc/mime.types", ext, part))
 		return;
-#endif /* M_UNIX */
 
 #ifdef TIN_DEFAULTS_DIR
 	joinpath(buf, sizeof(buf), TIN_DEFAULTS_DIR, "mime.types");
@@ -190,12 +188,10 @@ lookup_extension(
 		return TRUE;
 	}
 
-#ifdef M_UNIX
 	if (_lookup_extension(extension, ext_len, "/etc/mime.types", type)) {
 		free(type);
 		return TRUE;
 	}
-#endif /* M_UNIX */
 
 #ifdef TIN_DEFAULTS_DIR
 	joinpath(buf, sizeof(buf), TIN_DEFAULTS_DIR, "mime.types");
