@@ -3,35 +3,38 @@
  *  Module    : misc.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2018-11-23
+ *  Updated   : 2019-09-19
  *  Notes     :
  *
- * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -248,7 +251,7 @@ backup_file(
  * prefix (= quote_chars), initials of the articles author
  * with_sig is set if the signature should be quoted
  *
- * TODO: rewrite from scratch, the code is awful
+ * TODO: rewrite from scratch, the code is awful.
  */
 void
 copy_body(
@@ -261,8 +264,13 @@ copy_body(
 	char buf[8192];
 	char buf2[8192];
 	char prefixbuf[256];
+	char *p = prefixbuf;
+	char *q = prefix;
 	int i;
 	int retcode;
+	size_t maxlen = sizeof(prefixbuf) - 1;
+	size_t ilen = strlen(initl);
+	t_bool initials = FALSE;
 	t_bool status_char;
 	t_bool status_space;
 
@@ -272,45 +280,39 @@ copy_body(
 		return;
 	}
 
-	if (strlen(prefix) > 240) /* truncate and terminate */
-		prefix[240] = '\0';
+	while(maxlen > 0 && *q) {
+		if (*q == '%' && *(q + 1) == 'I') {
+			if (maxlen < ilen) /* not enough space left for %I expansion */
+				break;
 
-	/* convert %S to %s, for compatibility reasons only */
-	if (strstr(prefix, "%S")) {
-		status_char = FALSE;
-		for (i = 0; prefix[i]; i++) {
-			if ((status_char) && (prefix[i] == 'S'))
-				prefix[i] = 's';
-			status_char = (prefix[i] == '%');
+			strcpy(p, initl);
+			maxlen -= ilen;
+			p += ilen;
+			q += 2; /* skip over "%I" */
+			initials = TRUE;
+		} else {
+			*p++ = *q++;
+			maxlen--;
 		}
 	}
+	*p = '\0';
 
-	/*
-	 * strip trailing space if tinrc.quote_style doesn't have its
-	 * QUOTE_COMPRESS flag set
-	 */
-	if (tinrc.quote_style & QUOTE_COMPRESS) {
-		if (strstr(prefix, "%s"))
-			snprintf(prefixbuf, sizeof(prefixbuf), prefix, initl);
-		else {
-			/* strip tailing space from quote-char for quoting quoted lines */
-			strcpy(prefixbuf, prefix);
-			if (prefixbuf[strlen(prefixbuf) - 1] == ' ')
-				prefixbuf[strlen(prefixbuf) - 1] = '\0';
-		}
-	} else
-		snprintf(prefixbuf, sizeof(prefixbuf), prefix, initl);
+	/* no QUOTE_COMPRESS with initials */
+	if ((tinrc.quote_style & QUOTE_COMPRESS) && !initials) {
+		if (prefixbuf[strlen(prefixbuf) - 1] == ' ')
+			prefixbuf[strlen(prefixbuf) - 1] = '\0';
+	}
 
 	/*
 	 * if raw_data is true, the signature is exceptionally quoted, even if
 	 * tinrc tells us not to do so. This extraordinary behavior occurs when
 	 * replying or following up with the 'raw' message shown.
 	 */
-
 	while (fgets(buf, (int) sizeof(buf), fp_ip) != NULL) {
 		if (!(tinrc.quote_style & QUOTE_SIGS) && !strcmp(buf, SIGDASHES) && !raw_data)
 			break;
-		if (strstr(prefix, "%s")) { /* initials wanted */
+
+		if (initials) { /* initials wanted */
 			if (buf[0] != '\n') { /* line is not empty */
 				if (strchr(buf, '>')) {
 					status_space = FALSE;
@@ -429,13 +431,13 @@ invoke_ispell(
 	 * Now separating the header and body in two different files so that
 	 * the header is not checked by ispell
 	 */
-#ifdef HAVE_LONG_FILE_NAMES
+#	ifdef HAVE_LONG_FILE_NAMES
 	snprintf(nam_body, sizeof(nam_body), "%s%s", nam, ".body");
 	snprintf(nam_head, sizeof(nam_head), "%s%s", nam, ".head");
-#else
+#	else
 	snprintf(nam_body, sizeof(nam_body), "%s%s", nam, ".b");
 	snprintf(nam_head, sizeof(nam_head), "%s%s", nam, ".h");
-#endif /* HAVE_LONG_FILE_NAMES */
+#	endif /* HAVE_LONG_FILE_NAMES */
 
 	if ((fp_all = fopen(nam, "r")) == NULL) {
 		perror_message(_(txt_cannot_open), nam);
@@ -609,7 +611,7 @@ tin_done(
 		while (i--) {
 			wrote_newsrc_lines = write_newsrc();
 			if ((wrote_newsrc_lines >= 0L) && (wrote_newsrc_lines >= read_newsrc_lines)) {
-				if (!batch_mode || verbose)
+				if (/* !batch_mode || */ verbose)
 					wait_message(0, _(txt_newsrc_saved));
 				break;
 			}
@@ -643,8 +645,7 @@ tin_done(
 #endif /* XFACE_ABLE */
 
 	/* Do this sometime after we save the newsrc in case this hangs up for any reason */
-	if (ret != NNTP_ERROR_EXIT)
-		nntp_close();			/* disconnect from NNTP server */
+	nntp_close((ret == NNTP_ERROR_EXIT));			/* disconnect from NNTP server */
 
 	free_all_arrays();
 
@@ -728,7 +729,6 @@ my_mkdir(
 }
 
 
-#ifdef M_UNIX
 void
 rename_file(
 	const char *old_filename,
@@ -741,11 +741,11 @@ rename_file(
 
 	unlink(new_filename);
 
-#	ifdef HAVE_LINK
+#ifdef HAVE_LINK
 	if (link(old_filename, new_filename) == -1)
-#	else
+#else
 	if (rename(old_filename, new_filename) < 0)
-#	endif /* HAVE_LINK */
+#endif /* HAVE_LINK */
 	{
 		if (errno == EXDEV) {	/* create & copy file across filesystem */
 			if ((fp_old = fopen(old_filename, "r")) == NULL) {
@@ -776,14 +776,13 @@ rename_file(
 			return;
 		}
 	}
-#	ifdef HAVE_LINK
+#ifdef HAVE_LINK
 	if (unlink(old_filename) == -1) {
 		perror_message(_(txt_rename_error), old_filename, new_filename);
 		return;
 	}
-#	endif /* HAVE_LINK */
+#endif /* HAVE_LINK */
 }
-#endif /* M_UNIX */
 
 
 /*
@@ -798,7 +797,7 @@ invoke_cmd(
 	t_bool save_cmd_line = cmd_line;
 #ifndef IGNORE_SYSTEM_STATUS
 	t_bool success;
-#endif /* IGNORE_SYSTEM_STATUS */
+#endif /* !IGNORE_SYSTEM_STATUS */
 
 	if (!save_cmd_line) {
 		EndWin();
@@ -906,19 +905,14 @@ dir_name(
 
 /*
  * Return TRUE if new mail has arrived
- *
- * TODO: why not cache the mailbox_name?
  */
 #define MAILDIR_NEW	"new"
 t_bool
 mail_check(
-	void)
+	const char *mailbox_name)
 {
-	const char *mailbox_name;
 	struct stat buf;
 
-	mailbox_name = get_val("MAIL", mailbox);
-
 	if (mailbox_name != NULL && stat(mailbox_name, &buf) >= 0) {
 		if ((int) (buf.st_mode & S_IFMT) == (int) S_IFDIR) { /* maildir setup */
 			char *maildir_box;
@@ -1465,14 +1459,15 @@ strfpath_cp(
 /*
  * strfpath - produce formatted pathname expansion. Handles following forms:
  *   ~/News    -> $HOME/News
- *   ~abc/News -> /usr/abc/News
+ *   ~abc/News -> /home/abc/News
  *   $var/News -> /env/var/News
  *   =file     -> $HOME/Mail/file
- *   =         -> $HOME/Mail/group.name
+ *   =         -> $HOME/Mail/group.name   (shorthand for =%G)
  *   +file     -> savedir/group.name/file
- *
- * Interestingly, %G is not documented as such and apparently unused
- *   ~/News/%G -> $HOME/News/group.name
+ *   %G        -> group.name              (group.name is a file )
+ *   %G/file   -> group.name/file         (group.name is a dir)
+ *   %P        -> group/name              (name is a file)
+ *   %P/file   -> group/name/file         (name is a dir)
  *
  * Inputs:
  *   format		The string to be converted
@@ -1484,8 +1479,6 @@ strfpath_cp(
  *   0			on error
  *   1			if generated pathname is a mailbox
  *   2			success
- *
- * TODO: add %X (Article number), %M (Message-ID)?
  */
 static int
 _strfpath(
@@ -1551,13 +1544,13 @@ _strfpath(
 			case '$':	/* Read the envvar and use its value */
 				i = 0;
 				format++;
-				if (*format && *format == '{') {
+				if (*format == '{') {
 					format++;
 					while (*format && !(strchr("}-", *format)))
 						tbuf[i++] = *format++;
 					tbuf[i] = '\0';
 					i = 0;
-					if (*format && *format == '-') {
+					if (*format == '-') {
 						format++;
 						while (*format && *format != '}')
 							defbuf[i++] = *format++;
@@ -1646,20 +1639,42 @@ _strfpath(
 
 			case '%':	/* Different forms of parsing cmds */
 				format++;
-				if (*format && *format == 'G' && group != NULL) {
+				if (group != NULL && *format == 'G') {
 					memset(tbuf, 0, sizeof(tbuf));
 					STRCPY(tbuf, group->name);
 					i = strlen(tbuf);
 					if (((str + i) < (endp - 1)) && (i > 0)) {
 						strcpy(str, tbuf);
 						str += i;
-						break;
 					} else {
 						str[0] = '\0';
 						return 0;
 					}
-				} else
-					*str++ = *format;
+					break;
+				}
+				if (group != NULL && *format == 'P') {
+					char *pbuf = my_malloc(strlen(group->name) + 2); /* trailing "/\0" */
+
+					make_group_path(group->name, pbuf);
+					if ((i = strlen(pbuf)))
+						pbuf[i--] = '\0'; /* remove trailing '/' */
+					else {
+						str[0] = '\0';
+						free(pbuf);
+						return 0;
+					}
+					if (((str + i) < (endp - 1)) && (i > 0)) {
+						strcpy(str, pbuf);
+						free(pbuf);
+						str += i;
+					} else {
+						str[0] = '\0';
+						free(pbuf);
+						return 0;
+					}
+					break;
+				}
+				*str++ = *format;
 				/* FALLTHROUGH */
 			default:
 				break;
@@ -2054,9 +2069,8 @@ make_group_path(
 	char *path)
 {
 	while (*name) {
-		*path = ((*name == '.') ? '/' : *name);
+		*path++ = ((*name == '.') ? '/' : *name);
 		name++;
-		path++;
 	}
 	*path++ = '/';
 	*path = '\0';
@@ -2076,10 +2090,11 @@ make_base_group_path(
 	char *group_path,
 	size_t group_path_len)
 {
-	char buf[LEN];
+	char *buf = my_malloc(strlen(group_name) + 2); /* trailing "/\0" */
 
 	make_group_path(group_name, buf);
 	joinpath(group_path, group_path_len, base_dir, buf);
+	free(buf);
 }
 
 
@@ -2099,25 +2114,6 @@ cleanup_tmp_files(
 }
 
 
-#ifndef M_UNIX
-void
-make_post_process_cmd(
-	char *cmd,
-	char *dir,
-	char *file)
-{
-	char buf[LEN];
-	char currentdir[PATH_LEN];
-
-	get_cwd(currentdir);
-	chdir(dir);
-	sh_format(buf, sizeof(buf), cmd, file);
-	invoke_cmd(buf);
-	chdir(currentdir);
-}
-#endif /* !M_UNIX */
-
-
 /*
  * returns filesize in bytes
  * -1 in case of an error (file not found, or !S_IFREG)
@@ -2147,9 +2143,7 @@ file_mtime(
 
 
 /*
- * TODO: this seems to be unix specific, avoid !M_UNIX calls or
- *       add code for other OS
- *       this feature also isn't documented anywhere
+ * TODO: this feature isn't documented anywhere
  */
 char *
 random_organization(
@@ -2161,7 +2155,7 @@ random_organization(
 
 	*selorg = '\0';
 
-	if (*in_org != '/')	/* M_UNIXism?! */
+	if (*in_org != '/')
 		return in_org;
 
 	srand((unsigned int) time(NULL));
@@ -2414,13 +2408,13 @@ buffer_to_local(
 			cd1 = iconv_open("UCS-4", network_charset);
 			cd2 = iconv_open(clocal_charset, "UCS-4");
 			if (cd0 != (iconv_t) (-1) && cd1 != (iconv_t) (-1) && cd2 != (iconv_t) (-1)) {
-				ICONV_CONST char *inbuf;
 				char unknown = '?';
-				ICONV_CONST char *unknown_ascii = &unknown;
 				char *unknown_buf;
 				char unknown_ucs4[4];
 				char *obuf, *outbuf;
 				char *tmpbuf, *tbuf;
+				ICONV_CONST char *inbuf;
+				ICONV_CONST char *unknown_ascii = &unknown;
 				ICONV_CONST char *cur_inbuf;
 				int used;
 				size_t inbytesleft = 1;
@@ -3500,7 +3494,7 @@ gnksa_do_check_from(
 
 #ifdef DEBUG
 	if (debug & DEBUG_MISC)
-		wait_message(0, "From:=[%s]", from);
+		debug_print_file("GNKSA", "From:=[%s]", from);
 #endif /* DEBUG */
 
 	/* split from */
@@ -3510,7 +3504,7 @@ gnksa_do_check_from(
 
 #ifdef DEBUG
 	if (debug & DEBUG_MISC)
-		wait_message(0, "address=[%s]", address);
+		debug_print_file("GNKSA", "address=[%s]", address);
 #endif /* DEBUG */
 
 	/* parse address */
@@ -3522,12 +3516,17 @@ gnksa_do_check_from(
 
 #ifdef DEBUG
 		if (debug & DEBUG_MISC)
-			wait_message(0, "FQDN=[%s]", addr_begin);
+			debug_print_file("GNKSA", "FQDN=[%s]", addr_begin);
 #endif /* DEBUG */
 
 		/* convert FQDN part to lowercase */
 		str_lwr(addr_begin);
 
+#ifdef DEBUG
+		if (debug & DEBUG_MISC)
+			debug_print_file("GNKSA", "str_lwr(FQDN)=[%s]", addr_begin);
+#endif /* DEBUG */
+
 		if ((result = gnksa_check_domain(addr_begin)) != GNKSA_OK
 		    && (code == GNKSA_OK)) /* error detected */
 			code = result;
@@ -3542,7 +3541,7 @@ gnksa_do_check_from(
 
 #ifdef DEBUG
 	if (debug & DEBUG_MISC)
-		wait_message(0, "realname=[%s]", realname);
+		debug_print_file("GNKSA", "realname=[%s]", realname);
 #endif /* DEBUG */
 
 	/* check realname */
@@ -3555,9 +3554,9 @@ gnksa_do_check_from(
 #ifdef DEBUG
 	if (debug & DEBUG_MISC) { /* TODO: dump to a file instead of wait_message() */
 		if (code != GNKSA_OK)
-			wait_message(2, "From:=[%s], GNKSA=[%d]", from, code);
+			debug_print_file("GNKSA", "From:=[%s], GNKSA=[%d]", from, code);
 		else
-			wait_message(0, "GNKSA=[%d]", code);
+			debug_print_file("GNKSA", "GNKSA=[%d]", code);
 	}
 #endif /* DEBUG */
 
@@ -3770,7 +3769,7 @@ idna_decode(
 #	if defined(HAVE_LIBIDNKIT) && defined(HAVE_IDN_DECODENAME)
 	{
 		idn_result_t res;
-		char *q, *r = NULL;
+		char *q, *r;
 
 		if ((q = strrchr(out, '@'))) {
 			q++;
@@ -3800,10 +3799,10 @@ idna_decode(
 		UChar dest[1024];
 		UErrorCode err = U_ZERO_ERROR;
 		char *s;
-#ifdef HAVE_LIBICUUC_46_API
+#		ifdef HAVE_LIBICUUC_46_API
 		UIDNA *uts46;
 		UIDNAInfo info = UIDNA_INFO_INITIALIZER;
-#endif /* HAVE_LIBICUUC_46_API */
+#		endif /* HAVE_LIBICUUC_46_API */
 
 		if ((s = strrchr(out, '@')))
 			s++;
@@ -3811,13 +3810,13 @@ idna_decode(
 			s = out;
 
 		src = char2UChar(s);
-#ifndef HAVE_LIBICUUC_46_API
+#		ifndef HAVE_LIBICUUC_46_API
 		uidna_IDNToUnicode(src, -1, dest, 1023, UIDNA_USE_STD3_RULES, NULL, &err);
-#else
+#		else
 		uts46 = uidna_openUTS46(UIDNA_USE_STD3_RULES, &err);
 		uidna_nameToUnicode(uts46, src, u_strlen(src), dest, 1023, &info, &err);
 		uidna_close(uts46);
-#endif /* !HAVE_LIBICUUC_46_API */
+#		endif /* !HAVE_LIBICUUC_46_API */
 		free(src);
 		if (!(U_FAILURE(err))) {
 			char *t;
