@@ -3,7 +3,7 @@
  *  Module    : nntplib.c
  *  Author    : S. Barber & I. Lea
  *  Created   : 1991-01-12
- *  Updated   : 2017-11-06
+ *  Updated   : 2019-07-16
  *  Notes     : NNTP client routines taken from clientlib.c 1.5.11 (1991-02-10)
  *  Copyright : (c) Copyright 1991-99 by Stan Barber & Iain Lea
  *              Permission is hereby granted to copy, reproduce, redistribute
@@ -58,8 +58,7 @@ static TCP *nntp_rd_fp = NULL;
 	static int mode_reader(t_bool *sec);
 	static int reconnect(int retry);
 	static int server_init(char *machine, const char *cservice, unsigned short port, char *text, size_t mlen);
-	static int check_extensions(void);
-	static void close_server(void);
+	static void close_server(t_bool send_no_quit);
 	static void list_motd(void);
 #	ifdef INET6
 		static int get_tcp6_socket(char *machine, unsigned short port);
@@ -188,7 +187,7 @@ getserverbyfile(
  *
  *	Parameters:	"machine" is the machine to connect to.
  *			"service" is the service to connect to on the machine.
- *			"port" is the servive port to connect to.
+ *			"port" is the service port to connect to.
  *
  *	Returns:	server's initial response code
  *			or -errno
@@ -243,11 +242,14 @@ server_init(
 
 	if ((nntp_rd_fp = (TCP *) s_fdopen(sockt_rd, "r")) == NULL) {
 		perror("server_init: fdopen() #1");
+		s_close(sockt_rd);
 		return -errno;
 	}
 
 	if ((sockt_wr = s_dup(sockt_rd)) < 0) {
 		perror("server_init: dup()");
+		s_fclose(nntp_rd_fp);
+		nntp_rd_fp = NULL;
 		return -errno;
 	}
 
@@ -261,6 +263,7 @@ server_init(
 #	else
 	if ((nntp_wr_fp = (TCP *) s_fdopen(sockt_wr, "w")) == NULL) {
 		perror("server_init: fdopen() #2");
+		s_close(sockt_wr);
 		s_fclose(nntp_rd_fp);
 		nntp_rd_fp = NULL;
 		return -errno;
@@ -406,7 +409,9 @@ get_tcp_socket(
 	int x = 0;
 	char **cp;
 #			endif /* h_addr */
+#			ifdef HAVE_HOSTENT_H_ADDR_LIST
 	static char *alist[2] = {0, 0};
+#			endif /* HAVE_HOSTENT_H_ADDR_LIST */
 	static struct hostent def;
 	static struct in_addr defaddr;
 	static char namebuf[256];
@@ -437,8 +442,12 @@ get_tcp_socket(
 		/* Raw ip address, fake */
 		STRCPY(namebuf, machine);
 		def.h_name = (char *) namebuf;
+#			ifdef HAVE_HOSTENT_H_ADDR_LIST
 		def.h_addr_list = alist;
 		def.h_addr_list[0] = (char *) &defaddr;
+#			else
+		def.h_addr = (char *) &defaddr;
+#			endif /* HAVE_HOSTENT_H_ADDR_LIST */
 		def.h_length = sizeof(struct in_addr);
 		def.h_addrtype = AF_INET;
 		def.h_aliases = 0;
@@ -554,9 +563,11 @@ get_tcp_socket(
 	}
 
 	/* And then connect */
-
+#				ifdef HAVE_HOSTENT_H_ADDR_LIST
 	memcpy((char *) &sock_in.sin_addr, hp->h_addr_list[0], hp->h_length);
-
+#				else
+	memcpy((char *) &sock_in.sin_addr, hp->h_addr, hp->h_length);
+#				endif /* HAVE_HOSTENT_H_ADDR_LIST */
 	if (connect(s, (struct sockaddr *) &sock_in, sizeof(sock_in)) < 0) {
 		save_errno = errno;
 		perror("connect");
@@ -564,9 +575,9 @@ get_tcp_socket(
 		return -save_errno;
 	}
 
-#			endif /* !EXCELAN */
-#		endif /* !h_addr */
-#	endif /* !TLI */
+#			endif /* EXCELAN */
+#		endif /* h_addr */
+#	endif /* TLI */
 	return s;
 }
 #endif /* NNTP_ABLE && !INET6 */
@@ -593,7 +604,7 @@ get_tcp6_socket(
 {
 	char mymachine[MAXHOSTNAMELEN + 1];
 	char myport[12];
-	int s = -1, err;
+	int s = -1, err, ec = 0, es = 0;
 	struct addrinfo hints, *res, *res0;
 
 	snprintf(mymachine, sizeof(mymachine), "%s", machine);
@@ -620,22 +631,27 @@ get_tcp6_socket(
 	}
 	err = -1;
 	for (res = res0; res; res = res->ai_next) {
-		if ((s = socket(res->ai_family, res->ai_socktype, res->ai_protocol)) < 0)
+		if ((s = socket(res->ai_family, res->ai_socktype, res->ai_protocol)) < 0) {
+			es = errno;
 			continue;
-		if (connect(s, res->ai_addr, res->ai_addrlen) != 0)
+		}
+		if (connect(s, res->ai_addr, res->ai_addrlen) != 0) {
+			ec = errno;
 			s_close(s);
-		else {
-			err = 0;
+		} else {
+			es = ec = err = 0;
 			break;
 		}
 	}
 	if (res0 != NULL)
 		freeaddrinfo(res0);
 	if (err < 0) {
-		/*
-		 * TODO: issue a more useful error-message
-		 */
 		my_fprintf(stderr, "%s", _(txt_error_socket_or_connect_problem));
+		if (es)
+			my_fprintf(stderr, "\tsocket(2): %s\n", strerror(es));
+		if (ec)
+			my_fprintf(stderr, "\tconnect(2): %s\n", strerror(ec));
+		sleep(3);
 		return -1;
 	}
 	return s;
@@ -837,7 +853,7 @@ reconnect(
 		if (retry > NNTP_TRY_RECONNECT) {
 #	ifdef DEBUG
 			/* TODO: -> lang.c */
-			if (debug & DEBUG_NNTP)
+			if ((debug & DEBUG_NNTP) && verbose > 1)
 				debug_print_file("NNTP", "reconnect(%d) limit %d reached, giving up.", retry, NNTP_TRY_RECONNECT);
 #	endif /* DEBUG */
 		}
@@ -949,8 +965,8 @@ get_server(
 			 * Use standard NNTP closing message and response code if user is
 			 * quitting tin and leave loop.
 			 */
-			strncpy(string, _(txt_nntp_ok_goodbye), size - 2);
-			strcat(string, cCRLF);		/* tin_fgets() needs CRLF */
+			strncpy(string, _(txt_nntp_ok_goodbye), size - 3);
+			strcat(string, "\r\n");		/* tin_fgets() needs CRLF */
 			break;
 		}
 	}
@@ -975,18 +991,25 @@ get_server(
  */
 static void
 close_server(
-	void)
+	t_bool send_no_quit)
 {
-	if (nntp_wr_fp == NULL || nntp_rd_fp == NULL)
-		return;
+	if (!send_no_quit && nntp_wr_fp && nntp_rd_fp) {
 
-	if (!batch_mode || verbose)
-		my_fputs(_(txt_disconnecting), stdout);
-	nntp_command("QUIT", OK_GOODBYE, NULL, 0);
-	quitting = TRUE;										/* Don't reconnect just for this */
+		if (!batch_mode || verbose) {
+			char *msg;
 
-	(void) s_fclose(nntp_wr_fp);
-	(void) s_fclose(nntp_rd_fp);
+			msg = strunc(_(txt_disconnecting), cCOLS - 1);
+			my_fputs(msg, stdout);
+			my_fputc('\n', stdout);
+			free(msg);
+		}
+		nntp_command("QUIT", OK_GOODBYE, NULL, 0);
+		quitting = TRUE;										/* Don't reconnect just for this */
+	}
+	if (nntp_wr_fp)
+		(void) s_fclose(nntp_wr_fp);
+	if (nntp_rd_fp)
+		(void) s_fclose(nntp_rd_fp);
 	s_end();
 	nntp_wr_fp = nntp_rd_fp = NULL;
 }
@@ -999,9 +1022,9 @@ close_server(
  *
  * Sets up: t_capabilities nntp_caps
  */
-static int
+int
 check_extensions(
-	void)
+	int rvl)
 {
 	char *d;
 	char *ptr;
@@ -1010,7 +1033,9 @@ check_extensions(
 	int ret = 0;
 
 	buf[0] = '\0';
-	i = new_nntp_command("CAPABILITIES", INF_CAPABILITIES, buf, sizeof(buf));
+
+	/* rvl > 0 = manually send "CAPABILITIES" to avoid endless AUTH loop */
+	i = rvl ? rvl : new_nntp_command("CAPABILITIES", INF_CAPABILITIES, buf, sizeof(buf));
 	switch (i) {
 		case INF_CAPABILITIES:
 			/* clear capabilities */
@@ -1023,6 +1048,8 @@ check_extensions(
 			nntp_caps.list_active_times = FALSE;
 			nntp_caps.list_distrib_pats = FALSE;
 			nntp_caps.list_headers = FALSE;
+			FreeAndNull(nntp_caps.headers_range);
+			FreeAndNull(nntp_caps.headers_id);
 			nntp_caps.list_newsgroups = FALSE;
 			nntp_caps.list_overview_fmt = FALSE;
 			nntp_caps.list_motd = FALSE;
@@ -1030,7 +1057,7 @@ check_extensions(
 			nntp_caps.list_distributions = FALSE;
 			nntp_caps.list_moderators = FALSE;
 			nntp_caps.list_counts = FALSE;
-			nntp_caps.xpat = TRUE; /* only used in select.c:lookup_msgid(); toggles to false if fails, INN > 2.7.0 announces it */
+			nntp_caps.xpat = TRUE; /* toggles to false if fails, INN > 2.7.0 announces it */
 			nntp_caps.hdr = FALSE;
 			nntp_caps.hdr_cmd = NULL;
 			nntp_caps.over = FALSE;
@@ -1045,21 +1072,21 @@ check_extensions(
 			nntp_caps.sasl = SASL_NONE;
 			nntp_caps.compress = FALSE;
 			nntp_caps.compress_algorithm = COMPRESS_NONE;
-#if 0
+#	if 0
 			nntp_caps.streaming = FALSE;
 			nntp_caps.ihave = FALSE;
-#endif /* 0 */
-#ifndef BROKEN_LISTGROUP
+#	endif /* 0 */
+#	ifndef BROKEN_LISTGROUP
 			nntp_caps.broken_listgroup = FALSE;
-#else
+#	else
 			nntp_caps.broken_listgroup = TRUE;
-#endif /* !BROKEN_LISTGROUP */
+#	endif /* !BROKEN_LISTGROUP */
 
 			while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
-#		ifdef DEBUG
+#	ifdef DEBUG
 				if (debug & DEBUG_NNTP)
 					debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 				/* look for version number(s) */
 				if (!nntp_caps.version && nntp_caps.type == CAPABILITIES) {
 					if (!strncasecmp(ptr, "VERSION", 7)) {
@@ -1147,6 +1174,8 @@ check_extensions(
 					else if (!strncasecmp(ptr, &xhdr_cmds[1], strlen(&xhdr_cmds[1]))) {
 						nntp_caps.hdr_cmd = &xhdr_cmds[1];
 						nntp_caps.list_headers = nntp_caps.hdr = TRUE;
+						nntp_caps.headers_range = my_strdup("");
+						nntp_caps.headers_id = my_strdup("");
 					} else if (!strncasecmp(ptr, "AUTHINFO", 8)) {
 						d = ptr + 8;
 						d = strpbrk(d, " \t");
@@ -1224,7 +1253,7 @@ check_extensions(
 
 		/*
 		 * XanaNewz 2 Server Version 2.0.0.3 doesn't know CAPABILITIES
-		 * but respondes with 400 _without_ closing the connection. If
+		 * but responds with 400 _without_ closing the connection. If
 		 * you use tin on a XanaNewz 2 Server comment out the following
 		 * case.
 		 */
@@ -1255,8 +1284,8 @@ mode_reader(
 	if (!nntp_caps.reader) {
 		char line[NNTP_STRLEN];
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "mode_reader() MODE READER");
+		if ((debug & DEBUG_NNTP) && verbose > 1)
+			debug_print_file("NNTP", "mode_reader(MODE READER)");
 #	endif /* DEBUG */
 		DEBUG_IO((stderr, "nntp_command(MODE READER)\n"));
 		put_server("MODE READER");
@@ -1332,7 +1361,7 @@ nntp_open(
 		return 0;
 
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "nntp_open() BEGIN");
 #	endif /* DEBUG */
 
@@ -1350,7 +1379,7 @@ nntp_open(
 	}
 
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "nntp_open() %s:%d", nntp_server, nntp_tcp_port);
 #	endif /* DEBUG */
 
@@ -1361,7 +1390,7 @@ nntp_open(
 		my_fputc('\n', stdout);
 
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "nntp_open() %s", line);
 #	endif /* DEBUG */
 
@@ -1420,7 +1449,7 @@ nntp_open(
 	 *       RFC 4643).
 	 */
 	if (nntp_caps.type != BROKEN)
-		check_extensions();
+		check_extensions(0);
 
 	/*
 	 * If the user wants us to authenticate on connection startup, do it now.
@@ -1435,8 +1464,8 @@ nntp_open(
 			char buf[NNTP_STRLEN];
 
 #	ifdef DEBUG
-			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "nntp_open() MODE READER");
+			if ((debug & DEBUG_NNTP) && verbose > 1)
+				debug_print_file("NNTP", "nntp_open(MODE READER)");
 #	endif /* DEBUG */
 			put_server("MODE READER");
 			switch (get_only_respcode(buf, sizeof(buf))) {
@@ -1449,21 +1478,18 @@ nntp_open(
 				default:
 					break;
 			}
-			check_extensions();
+			check_extensions(0);
 		}
 	}
 
 	if (force_auth_on_conn_open) {
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "nntp_open() authenticate(force_auth_on_conn_open)");
+		if ((debug & DEBUG_NNTP) && verbose > 1)
+			debug_print_file("NNTP", "nntp_open(authenticate(force_auth_on_conn_open))");
 #	endif /* DEBUG */
 
 		if (!authenticate(nntp_server, userid, FALSE))	/* 3rd parameter is FALSE as we need to get prompted for username password here */
 			return -1;
-
-		if (nntp_caps.type == CAPABILITIES)
-			check_extensions();
 	}
 
 	if ((nntp_caps.type == CAPABILITIES && nntp_caps.mode_reader) || nntp_caps.type != CAPABILITIES) {
@@ -1474,11 +1500,15 @@ nntp_open(
 			return ret;
 		}
 		if (nntp_caps.type == CAPABILITIES)
-			check_extensions();
+			check_extensions(0);
 	}
 
 	if (nntp_caps.type == CAPABILITIES) {
 		if (!nntp_caps.reader) {
+#	ifdef DEBUG
+			if ((debug & DEBUG_NNTP) && verbose > 1)
+				debug_print_file("NNTP", "CAPABILITIES did not announce READER");
+#	endif /* DEBUG */
 			error_message(2, _("CAPABILITIES did not announce READER")); /* TODO: -> lang.c */
 			return -1; /* give up */
 		}
@@ -1488,7 +1518,7 @@ nntp_open(
 	if (!is_reconnect && *line) {
 #	if 0
 	/*
-	 * gives wrong results if RFC 3977 server requestes auth after
+	 * gives wrong results if RFC 3977 server requests auth after
 	 * CAPABILITIES is parsed (with no posting allowed) and after auth
 	 * posting is allowed. as we will inform the user later on when he
 	 * actually tries to post it should do no harm to skip this message
@@ -1550,7 +1580,7 @@ nntp_open(
 				case OK_XOVER:	/* unexpected multiline ok, e.g.: Synchronet 3.13 NNTP Service 1.92 or on reconnect if last cmd was GROUP */
 					nntp_caps.over_cmd = &xover_cmds[i];
 #	ifdef DEBUG
-					if (debug & DEBUG_NNTP)
+					if ((debug & DEBUG_NNTP) && verbose > 1)
 						debug_print_file("NNTP", "nntp_open() %s skipping data", &xover_cmds[i]);
 #	endif /* DEBUG */
 					while (tin_fgets(FAKE_NNTP_FP, FALSE))
@@ -1572,10 +1602,10 @@ nntp_open(
 
 				case 221:	/* unexpected multiline ok, e.g.: SoftVelocity Discussions 2.5q */
 					nntp_caps.hdr_cmd = &xhdr_cmds[i];
-#		ifdef DEBUG
-					if (debug & DEBUG_NNTP)
+#	ifdef DEBUG
+					if ((debug & DEBUG_NNTP) && verbose > 1)
 						debug_print_file("NNTP", "nntp_open() %s skipping data", &xhdr_cmds[i]);
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 					while (tin_fgets(FAKE_NNTP_FP, FALSE))
 						;
 					j = -1;
@@ -1587,9 +1617,9 @@ nntp_open(
 					break;
 			}
 		}
-		/* no XPAT probing here, we do it in select.c:lookup_msgid() as that's the only place we use it */
+		/* no XPAT probing here, we do when it's needed */
 		nntp_caps.xpat = TRUE;
-#		if 0
+#	if 0
 		switch (new_nntp_command("XPAT Newsgroups <0> *", ERR_NOART, line, sizeof(line))) {
 			case ERR_NOART:
 				nntp_caps.xpat = TRUE;
@@ -1598,7 +1628,7 @@ nntp_open(
 			default:
 				break;
 		}
-#		endif /* 0 */
+#	endif /* 0 */
 	} else {
 		if (!nntp_caps.over_cmd) {
 			/*
@@ -1611,7 +1641,7 @@ nntp_open(
 				case OK_XOVER:	/* unexpected multiline ok, e.g.: Synchronet 3.13 NNTP Service 1.92 or on reconnect if last cmd was GROUP */
 					nntp_caps.over_cmd = xover_cmds;
 #	ifdef DEBUG
-					if (debug & DEBUG_NNTP)
+					if ((debug & DEBUG_NNTP) && verbose > 1)
 						debug_print_file("NNTP", "nntp_open() %s skipping data", xover_cmds);
 #	endif /* DEBUG */
 					while (tin_fgets(FAKE_NNTP_FP, FALSE))
@@ -1633,10 +1663,10 @@ nntp_open(
 
 				case 221:	/* unexpected multiline ok, e.g.: SoftVelocity Discussions 2.5q */
 					nntp_caps.hdr_cmd = xhdr_cmds;
-#		ifdef DEBUG
-					if (debug & DEBUG_NNTP)
+#	ifdef DEBUG
+					if ((debug & DEBUG_NNTP) && verbose > 1)
 						debug_print_file("NNTP", "nntp_open() %s skipping data", xhdr_cmds);
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 					while (tin_fgets(FAKE_NNTP_FP, FALSE))
 						;
 					break;
@@ -1691,15 +1721,15 @@ nntp_open(
  */
 void
 nntp_close(
-	void)
+	t_bool send_no_quit)
 {
 #ifdef NNTP_ABLE
 	if (read_news_via_nntp && !read_saved_news) {
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "nntp_close() END");
+		if ((debug & DEBUG_NNTP) && verbose > 1)
+			debug_print_file("NNTP", "nntp_close(%s) END", bool_unparse(send_no_quit));
 #	endif /* DEBUG */
-		close_server();
+		close_server(send_no_quit);
 	}
 #endif /* NNTP_ABLE */
 }
@@ -1728,8 +1758,8 @@ get_only_respcode(
 
 	if (tin_errno || ptr == NULL) {
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "<<<%sError: tin_error<>0 or ptr==NULL in get_only_respcode()", logtime());
+		if ((debug & DEBUG_NNTP) && verbose > 1)
+			debug_print_file("NNTP", "Error: tin_error<>0 or ptr==NULL in get_only_respcode()");
 #	endif /* DEBUG */
 		return -1;
 	}
@@ -1755,7 +1785,7 @@ get_only_respcode(
 		 * If so, retrying will force a reconnect.
 		 */
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
+		if ((debug & DEBUG_NNTP) && verbose > 1)
 			debug_print_file("NNTP", "get_only_respcode() timeout");
 #	endif /* DEBUG */
 		put_server(last_put);
@@ -1763,8 +1793,8 @@ get_only_respcode(
 
 		if (tin_errno || ptr == NULL) {
 #	ifdef DEBUG
-			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<<%sError: tin_errno<>0 or ptr==NULL in get_only_respcode(retry)", logtime());
+			if ((debug & DEBUG_NNTP) && verbose > 1)
+				debug_print_file("NNTP", "Error: tin_errno<>0 or ptr==NULL in get_only_respcode(retry)");
 #	endif /* DEBUG */
 			return -1;
 		}
@@ -1796,7 +1826,7 @@ get_only_respcode(
  * necessary after a timeout.
  *
  * TODO: make this handle 401 and 483 (RFC 3977) return codes.
- *       as 401 requires to examine the returned text besides the
+ *       as 401 requires the examination of the returned text besides the
  *       return value, we have to "fix" all nntp_command(..., NULL, 0) and
  *       get_only_respcode(NULL, 0) calls to do this properly.
  */
@@ -1815,7 +1845,7 @@ get_respcode(
 		 * Server requires authentication.
 		 */
 #	ifdef DEBUG
-		if (debug & DEBUG_NNTP)
+		if ((debug & DEBUG_NNTP) && verbose > 1)
 			debug_print_file("NNTP", "get_respcode() authentication");
 #	endif /* DEBUG */
 		STRCPY(savebuf, last_put);
@@ -1823,10 +1853,9 @@ get_respcode(
 		if (!authenticate(nntp_server, userid, FALSE))
 			tin_done(EXIT_FAILURE, _(txt_auth_failed), nntp_caps.type == CAPABILITIES ? ERR_AUTHFAIL : ERR_ACCESS);
 
-		if (nntp_caps.type == CAPABILITIES) {
-			check_extensions();
+		if (nntp_caps.type == CAPABILITIES)
 			can_post = nntp_caps.post && !force_no_post;
-		} else {
+		else {
 			put_server("MODE READER");
 			if (get_only_respcode(message, mlen) == OK_CANPOST)
 				can_post = TRUE && !force_no_post;
@@ -1849,8 +1878,8 @@ get_respcode(
 
 		if (tin_errno) {
 #	ifdef DEBUG
-			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<<%sError: tin_errno <> 0", logtime());
+			if ((debug & DEBUG_NNTP) && verbose > 1)
+				debug_print_file("NNTP", "Error: tin_errno <> 0");
 #	endif /* DEBUG */
 			return -1;
 		}
@@ -1889,7 +1918,7 @@ nntp_command(
 {
 DEBUG_IO((stderr, "nntp_command(%s)\n", command));
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "nntp_command(%s)", command);
 #	endif /* DEBUG */
 	put_server(command);
@@ -1897,7 +1926,7 @@ DEBUG_IO((stderr, "nntp_command(%s)\n", command));
 	if (!bool_equal(dangerous_signal_exit, TRUE)) {
 		if (get_respcode(message, mlen) != success) {
 #	ifdef DEBUG
-			if (debug & DEBUG_NNTP)
+			if ((debug & DEBUG_NNTP) && verbose > 1)
 				debug_print_file("NNTP", "nntp_command(%s) NOT_OK", command);
 #	endif /* DEBUG */
 			/* error_message(2, "%s", message); */
@@ -1905,7 +1934,7 @@ DEBUG_IO((stderr, "nntp_command(%s)\n", command));
 		}
 	}
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "nntp_command(%s) OK", command);
 #	endif /* DEBUG */
 	return FAKE_NNTP_FP;
@@ -1928,7 +1957,7 @@ new_nntp_command(
 
 DEBUG_IO((stderr, "new_nntp_command(%s)\n", command));
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "new_nntp_command(%s)", command);
 #	endif /* DEBUG */
 	put_server(command);
@@ -1936,14 +1965,14 @@ DEBUG_IO((stderr, "new_nntp_command(%s)\n", command));
 	if (!bool_equal(dangerous_signal_exit, TRUE)) {
 		if ((respcode = get_respcode(message, mlen)) != success) {
 #	ifdef DEBUG
-			if (debug & DEBUG_NNTP)
+			if ((debug & DEBUG_NNTP) && verbose > 1)
 				debug_print_file("NNTP", "new_nntp_command(%s) NOT_OK - Expected: %d, got: %d", command, success, respcode);
 #	endif /* DEBUG */
 			return respcode;
 		}
 	}
 #	ifdef DEBUG
-	if (debug & DEBUG_NNTP)
+	if ((debug & DEBUG_NNTP) && verbose > 1)
 		debug_print_file("NNTP", "new_nntp_command(%s) OK", command);
 #	endif /* DEBUG */
 	return respcode;
