@@ -3,38 +3,41 @@
  *  Module    : nrctbl.c
  *  Author    : Sven Paulus <sven@tin.org>
  *  Created   : 1996-10-06
- *  Updated   : 2009-07-17
+ *  Updated   : 2019-07-08
  *  Notes     : This module does the NNTP server name lookup in
  *              ~/.tin/newsrctable and returns the real hostname
  *              and the name of the newsrc file for a given
  *              alias of the server.
  *
- * Copyright (c) 1996-2018 Sven Paulus <sven@tin.org>
+ * Copyright (c) 1996-2020 Sven Paulus <sven@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -180,20 +183,21 @@ get_newsrcname(
 					newsrc_name[newsrc_name_len - 1] = '\0';
 				} else
 					joinpath(newsrc_name, newsrc_name_len, homedir, tmp_newsrc);
-			}
-			STRCPY(dir, newsrc_name);
-			if (strchr(dir, '/'))
-				*strrchr(dir, '/') = (char) 0;
 
-			if (!error) {
-			/*
-			 * TODO: shall we create a missing dir?
-			 *       currently something like
-			 *       ~/.tin/${NNTPSERVER-localhost}/.newsrc
-			 *       in newsrctable usually ends with
-			 *       "No permissions to go into /home/urs/.tin/${NNTPSERVER}"
-			 */
-			/* FIXME - write a global permssion check routine */
+				STRCPY(dir, newsrc_name);
+				if ((line_entry = strrchr(dir, '/'))) { /* dirname(newsrc_name) */
+					while (line_entry > &dir[0] && *line_entry == '/')
+						*line_entry-- = '\0';
+				}
+
+				/*
+				 * TODO: shall we create a missing dir?
+				 *       currently something like
+				 *       ~/.tin/${NNTPSERVER-localhost}/.newsrc
+				 *       in newsrctable usually ends with
+				 *       "No permissions to go into /home/urs/.tin/${NNTPSERVER}"
+				 */
+				/* FIXME - write a global permssion check routine */
 				if (access(dir, X_OK)) {
 					my_fprintf(stderr, _(txt_error_no_enter_permission), dir);
 					error = 1;
@@ -214,6 +218,7 @@ get_newsrcname(
 					error = 1;
 				}
 			}
+
 			if (error) {
 				char ch, default_ch = 'a';
 
@@ -242,7 +247,7 @@ get_newsrcname(
 
 					case 'a':
 						/*
-						 * FIXME this (e.g. the location of the alternativce name)
+						 * FIXME this (e.g. the location of the alternative name)
 						 * is not documented in the man page
 						 */
 						snprintf(name_found, sizeof(name_found), ".newsrc-%s", nntpserver_name);
