@@ -3,35 +3,38 @@
  *  Module    : save.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2017-08-21
+ *  Updated   : 2019-06-05
  *  Notes     :
  *
- * Copyright (c) 1991-2018 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -135,7 +138,6 @@ check_start_save_any_news(
 	FILE *fp_log = (FILE *) 0;
 	char *line;
 	char buf[LEN];
-	char group_path[PATH_LEN];
 	char path[PATH_LEN];
 	char logfile[PATH_LEN], savefile[PATH_LEN];
 	char subject[HEADER_LEN];
@@ -212,12 +214,14 @@ check_start_save_any_news(
 
 			if (function == SAVE_ANY_NEWS) {
 				char tmp[PATH_LEN];
+				char *group_path = my_malloc(strlen(group->name) + 2); /* trailing "/\0" */
 
+				make_group_path(group->name, group_path);
 				if (!strfpath((cmdline.args & CMDLINE_SAVEDIR) ? cmdline.savedir : tinrc.savedir, tmp, sizeof(tmp), group, FALSE))
 					joinpath(tmp, sizeof(tmp), homedir, DEFAULT_SAVEDIR);
 
-				make_group_path(group->name, group_path);
 				joinpath(path, sizeof(path), tmp, group_path);
+				free(group_path);
 				create_path(path);	/* TODO error handling */
 			}
 		}
@@ -573,7 +577,7 @@ save_and_process_art(
 
 	/*
 	 * Extract/view parts from multipart articles if required
-	 * libuu does this as part of it's own processing
+	 * libuu does this as part of its own processing
 	 */
 #ifndef HAVE_LIBUU
 	if (post_process) {
@@ -918,7 +922,7 @@ post_process_uud(
 		if ((fp_in = fopen(save[i].path, "r")) == NULL)
 			continue;
 
-		while (fgets(s, (int) sizeof(s), fp_in) != 0) {
+		while (fgets(s, (int) sizeof(s), fp_in) != NULL) {
 			switch (state) {
 				case INITIAL:
 					if (strncmp("begin ", s, 6) == 0) {
@@ -957,7 +961,7 @@ post_process_uud(
 
 				case MIDDLE:
 					/*
-					 * TODO: replace hardcoded length check (uue lines are not
+					 * TODO: replace hard coded length check (uue lines are not
 					 *       required to be 60 chars long (45 encoded chars)
 					 *       ('M' == 60 * 3 / 4 + ' ' == 77))
 					 */
@@ -1035,14 +1039,14 @@ post_process_uud(
 
 /*
  * Sum file - why do we bother to do this?
- * nuke code or add DONT_HAVE_PIPING and !M_UNIX -tree
+ * nuke code or add DONT_HAVE_PIPING -tree
  */
 static void
 sum_file(
 	const char *path,
 	const char *file)
 {
-#	if defined(M_UNIX) && defined(HAVE_SUM) && !defined(DONT_HAVE_PIPING)
+#	if defined(HAVE_SUM) && !defined(DONT_HAVE_PIPING)
 	FILE *fp_in;
 	char *ext;
 	char buf[LEN];
@@ -1070,7 +1074,7 @@ sum_file(
 		my_printf(cCRLF);
 	}
 	my_flush();
-#	endif /* M_UNIX && HAVE SUM && !DONT_HAVE_PIPING */
+#	endif /* HAVE SUM && !DONT_HAVE_PIPING */
 }
 #endif /* HAVE_LIBUU */
 
@@ -1190,14 +1194,10 @@ post_process_sh(
 
 		fclose(fp_out);
 		fp_out = NULL;
-#ifndef M_UNIX
-		make_post_process_cmd(DEFAULT_UNSHAR, file_out_dir, file_out);
-#else
 		sh_format(buf, sizeof(buf), "cd %s; sh %s", file_out_dir, file_out);
 		my_fputs(cCRLF, stdout);
 		my_flush();
 		invoke_cmd(buf);			/* Handles its own errors */
-#endif /* !M_UNIX */
 		unlink(file_out);
 	}
 }
@@ -1638,6 +1638,11 @@ attachment_page(
 				show_attachment_page();
 				break;
 
+			case GLOBAL_BUGREPORT:
+				bug_report();
+				show_attachment_page();
+				break;
+
 			case GLOBAL_FIRST_PAGE:
 				top_of_list();
 				break;
@@ -1837,7 +1842,7 @@ build_attachment_line(
 #endif /* USE_CURSES */
 
 	part = get_part(i);
-	namelen = strwidth(_(txt_attachment_no_name));
+	namelen = MIN(cCOLS - 13 - info_len - 8, strwidth(_(txt_attachment_no_name)));
 	tagged = get_tagged(i);
 
 	if (!(name = get_filename(part->params))) {
@@ -2263,7 +2268,7 @@ process_part(
 	const char *savepath,
 	enum action what)
 {
-	FILE *infile = NULL;
+	FILE *infile;
 	char buf[2048], buf2[2048];
 	int count;
 	int i, line_count;
