@@ -3,10 +3,10 @@
  *  Module    : string.c
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   : 1997-01-20
- *  Updated   : 2017-02-17
+ *  Updated   : 2019-01-08
  *  Notes     :
  *
- * Copyright (c) 1997-2018 Urs Janssen <urs@tin.org>
+ * Copyright (c) 1997-2019 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -69,7 +69,7 @@
  * special ltoa()
  * converts value into a string with a maxlen of digits (usually should be
  * >=4), last char may be one of the following:
- * 'k'ilo, 'M'ega, 'G'iga, 'T'erra, 'P'eta, 'E'xa, 'Z'etta, 'Y'otta,
+ * 'k'ilo, 'M'ega, 'G'iga, 'T'era, 'P'eta, 'E'xa, 'Z'etta, 'Y'otta,
  * 'X'ona, 'W'eka, 'V'unda, 'U'da (these last 4 are no official SI-prefixes)
  * or 'e' if an error occurs
  */
@@ -213,11 +213,11 @@ strcasestr(
 	h = haystack;
 	n = needle;
 	while (*haystack) {
-		if (tolower((unsigned char) *h) == tolower((unsigned char) *n)) {
+		if (my_tolower((unsigned char) *h) == my_tolower((unsigned char) *n)) {
 			h++;
 			n++;
 			if (!*n)
-				return haystack;
+				return (char *) haystack;
 		} else {
 			h = ++haystack;
 			n = needle;
@@ -243,6 +243,39 @@ mystrcat(
 	return len;
 }
 
+/*
+ * get around broken tolower()/toupper() macros on
+ * ancient BSDs (at least on sony news os)
+ */
+int
+my_tolower(
+int c)
+{
+#ifdef TOLOWER_BROKEN
+	if (c >= 'A' && c <= 'Z')
+		return (c - 'A' + 'a');
+	else
+		return (c);
+#else
+	return tolower(c);
+#endif /* TOLOWER_BROKEN */
+}
+
+
+int
+my_toupper(
+int c)
+{
+#ifdef TOUPPER_BROKEN
+	if (c >= 'a' && c <= 'z')
+		return (c - 'a' + 'A');
+	else
+		return (c);
+#else
+	return toupper(c);
+#endif /* TOUPPER_BROKEN */
+}
+
 
 void
 str_lwr(
@@ -251,7 +284,7 @@ str_lwr(
 	char *dst = str;
 
 	while (*str)
-		*dst++ = (char) tolower((unsigned char) *str++);
+		*dst++ = (char) my_tolower((unsigned char) *str++);
 
 	*dst = '\0';
 }
@@ -368,7 +401,7 @@ atol(
 
 #ifndef HAVE_STRTOL
 /* fix me - put me in tin.h */
-#	define DIGIT(x) (isdigit((unsigned char) x) ? ((x) - '0') : (10 + tolower((unsigned char) x) - 'a'))
+#	define DIGIT(x) (isdigit((unsigned char) x) ? ((x) - '0') : (10 + my_tolower((unsigned char) x) - 'a'))
 #	define MBASE 36
 long
 strtol(
@@ -422,7 +455,7 @@ OUT:
 
 #if !defined(HAVE_STRCASECMP) || !defined(HAVE_STRNCASECMP)
 	/* fix me - put me in tin.h */
-#	define FOLD_TO_UPPER(a)	(toupper((unsigned char) (a)))
+#	define FOLD_TO_UPPER(a)	(my_toupper((unsigned char) (a)))
 #endif /* !HAVE_STRCASECMP || !HAVE_STRNCASECMP */
 /*
  * strcmp that ignores case
@@ -690,11 +723,11 @@ sh_format(
 				 * the whole string rather than escaping individual chars.
 				 */
 				if (quote == '"') {
-					fix = (strchr(SH_DOUBLE, *src) != 0);
+					fix = (strchr(SH_DOUBLE, *src) != NULL);
 				} else if (quote == '\'') {
-					fix = (strchr(SH_SINGLE, *src) != 0);
+					fix = (strchr(SH_SINGLE, *src) != NULL);
 				} else
-					fix = (strchr(SH_META, *src) != 0);
+					fix = (strchr(SH_META, *src) != NULL);
 				if (fix) {
 					SH_FORMAT('\\');
 				}
@@ -755,7 +788,7 @@ strrstr(
 	const char *ptr;
 	size_t slen, plen;
 
-	if ((str != 0) && (pat != 0)) {
+	if ((str != NULL) && (pat != NULL)) {
 		slen = strlen(str);
 		plen = strlen(pat);
 
@@ -1025,7 +1058,7 @@ strwidth(
 #define TRUNC_TAIL	"..."
 /*
  * shortens 'mesg' that it occupies at most 'len' screen positions.
- * If it was nessary to truncate 'mesg', " ..." is appended to the
+ * If it was necessary to truncate 'mesg', " ..." is appended to the
  * resulting string (still 'len' screen positions wide).
  * The resulting string is stored in 'buf'.
  */
@@ -1202,35 +1235,77 @@ normalize(
 		int32_t needed, norm_len;
 		UChar *ustr, *norm;
 		UErrorCode status = U_ZERO_ERROR;
+#ifdef HAVE_UNICODE_UNORM2_H
+		static const char *uname[] = {"nfc", "nfkc", "nfkc_cf"}; /* */
+		const char *unamep;
+		UNormalization2Mode mode;
+#else
 		UNormalizationMode mode;
-
-		switch (tinrc.normalization_form) {
-			case NORMALIZE_NFD:
-				mode = UNORM_NFD;
-				break;
-
-			case NORMALIZE_NFC:
-				mode = UNORM_NFC;
-				break;
-
-			case NORMALIZE_NFKD:
-				mode = UNORM_NFKD;
-				break;
-
-			case NORMALIZE_NFKC:
-			default:
-				mode = UNORM_NFKC;
-		}
+#endif /* !HAVE_UNICODE_UNORM2_H */
 
 		/* convert to UTF-16 which is used internally by ICU */
 		if ((ustr = char2UChar(tmp)) == NULL) /* something went wrong, return the original string (as valid UTF8) */
 			return tmp;
 
+		switch (tinrc.normalization_form) {
+			case NORMALIZE_NFD:
+#ifdef HAVE_UNICODE_UNORM2_H
+				unamep = uname[0];
+				mode = UNORM2_DECOMPOSE;
+#else
+				mode = UNORM_NFD;
+#endif /* HAVE_UNICODE_UNORM2_H */
+				break;
+
+			case NORMALIZE_NFC:
+#ifdef HAVE_UNICODE_UNORM2_H
+				unamep = uname[0];
+				mode = UNORM2_COMPOSE;
+#else
+				mode = UNORM_NFC;
+#endif /* HAVE_UNICODE_UNORM2_H */
+				break;
+
+			case NORMALIZE_NFKD:
+#ifdef HAVE_UNICODE_UNORM2_H
+				unamep = uname[1];
+				mode = UNORM2_DECOMPOSE;
+#else
+				mode = UNORM_NFKD;
+#endif /* HAVE_UNICODE_UNORM2_H */
+				break;
+#ifdef HAVE_UNICODE_UNORM2_H
+			case NORMALIZE_NFKC_CF:
+				unamep = uname[2];
+				mode = UNORM2_COMPOSE;
+				break;
+#endif /* HAVE_UNICODE_UNORM2_H */
+
+			case NORMALIZE_NFKC:
+			default:
+#ifdef HAVE_UNICODE_UNORM2_H
+				unamep = uname[1];
+				mode = UNORM2_COMPOSE;
+#else
+				mode = UNORM_NFKC;
+#endif /* HAVE_UNICODE_UNORM2_H */
+		}
+
+#ifdef HAVE_UNICODE_UNORM2_H
+		needed = unorm2_normalize(unorm2_getInstance(NULL, unamep, mode, &status), ustr, -1, NULL, 0, &status);
+#else
 		needed = unorm_normalize(ustr, -1, mode, 0, NULL, 0, &status);
+#endif /* HAVE_UNICODE_UNORM2_H */
+
 		status = U_ZERO_ERROR;		/* reset status */
 		norm_len = needed + 1;
 		norm = my_malloc(sizeof(UChar) * norm_len);
+#ifdef HAVE_UNICODE_UNORM2_H
+		(void) unorm2_normalize(unorm2_getInstance(NULL, unamep, mode, &status), ustr, -1, norm, norm_len, &status);
+#else
 		(void) unorm_normalize(ustr, -1, mode, 0, norm, norm_len, &status);
+#endif /* HAVE_UNICODE_UNORM2_H */
+
 		if (U_FAILURE(status)) {
 			/* something went wrong, return the original string (as valid UTF8) */
 			free(ustr);
@@ -1302,21 +1377,22 @@ fmt_string(
 	const char *fmt,
 	...)
 {
-	char *str;
 	va_list ap;
+	size_t size = LEN;
+	char *str = my_malloc(size);
+	int used;
 
-	va_start(ap, fmt);
-#ifdef HAVE_VASPRINTF
-	if (vasprintf(&str, fmt, ap) == -1)	/* something went wrong */
-#endif /* HAVE_VASPRINTF */
-	{
-		size_t size = LEN;
+	while (1) {
+		va_start(ap, fmt);
+		used = vsnprintf(str, size, fmt, ap);
+		va_end(ap);
 
-		str = my_malloc(size);
-		/* TODO: realloc str if necessary */
-		vsnprintf(str, size, fmt, ap);
+		if (used > 0 && used < (int) size)
+			break;
+
+		size <<= 1;
+		str = my_realloc(str, size);
 	}
-	va_end(ap);
 
 	return str;
 }
