@@ -3,35 +3,38 @@
  *  Module    : xref.c
  *  Author    : I. Lea & H. Brugge
  *  Created   : 1993-07-01
- *  Updated   : 2016-06-02
+ *  Updated   : 2019-09-11
  *  Notes     :
  *
- * Copyright (c) 1993-2018 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1993-2020 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -80,8 +83,7 @@ overview_xref_support(
 	void)
 {
 	FILE *fp;
-	char *ptr;
-	char *p, *q;
+	char *ptr, *p;
 	t_bool supported = FALSE;
 	size_t res_fields = 9; /* initial number of overview fields */
 	size_t fields = 0;
@@ -117,7 +119,7 @@ overview_xref_support(
 						if (fields != 7) {
 							expensive_over_parse = TRUE;
 #ifdef DEBUG
-							if (debug & DEBUG_NNTP)
+							if ((debug & DEBUG_NNTP) && verbose > 1)
 								debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 7);
 #endif /* DEBUG */
 						}
@@ -130,7 +132,7 @@ overview_xref_support(
 						if (fields != 6) {
 							expensive_over_parse = TRUE;
 #ifdef DEBUG
-							if (debug & DEBUG_NNTP)
+							if ((debug & DEBUG_NNTP) && verbose > 1)
 								debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 6);
 #endif /* DEBUG */
 						}
@@ -143,19 +145,18 @@ overview_xref_support(
 				/* optional items require :full */
 				if (!strcasecmp(p, ":full")) {
 					ofmt[fields].type = OVER_T_FSTRING;
-					q = strchr(p, ':');
-					*(++q) = '\0';
+					*(++p) = '\0';
 					ofmt[fields].name = my_strdup(ptr);
 					if (fields < 7) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected > %d", ptr, fields, 7);
 #endif /* DEBUG */
 					}
 #ifdef DEBUG
 					else {
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d", ptr, fields);
 					}
 #endif /* DEBUG */
@@ -163,14 +164,14 @@ overview_xref_support(
 					continue;
 				}
 
-				/* madatory items */
+				/* mandatory items */
 				if (!strcasecmp(ptr, "Subject:")) {
 					ofmt[fields].type = OVER_T_STRING;
 					ofmt[fields].name = my_strdup(ptr);
 					if (fields != 1) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 1);
 #endif /* DEBUG */
 					}
@@ -183,7 +184,7 @@ overview_xref_support(
 					if (fields != 2) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 2);
 #endif /* DEBUG */
 					}
@@ -196,7 +197,7 @@ overview_xref_support(
 					if (fields != 3) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 3);
 #endif /* DEBUG */
 					}
@@ -209,7 +210,7 @@ overview_xref_support(
 					if (fields != 4) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 4);
 #endif /* DEBUG */
 					}
@@ -222,7 +223,7 @@ overview_xref_support(
 					if (fields != 5) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 5);
 #endif /* DEBUG */
 					}
@@ -235,7 +236,7 @@ overview_xref_support(
 					if (fields != 6) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 6);
 #endif /* DEBUG */
 					}
@@ -248,7 +249,7 @@ overview_xref_support(
 					if (fields != 7) {
 						expensive_over_parse = TRUE;
 #ifdef DEBUG
-						if (debug & DEBUG_NNTP)
+						if ((debug & DEBUG_NNTP) && verbose > 1)
 							debug_print_file("NNTP", "OVERVIEW.FMT: %s at position %d expected %d", ptr, fields, 7);
 #endif /* DEBUG */
 					}
@@ -272,7 +273,7 @@ overview_xref_support(
 
 	if (fields < 2) {
 #ifdef DEBUG
-		if (debug & DEBUG_NNTP)
+		if ((debug & DEBUG_NNTP) && verbose > 1)
 			debug_print_file("NNTP", fp ? "OVERVIEW.FMT: Empty response - using safe defaults" : "OVERVIEW.FMT: not advertized - using safe defaults");
 #endif /* DEBUG */
 		ofmt = my_realloc(ofmt, sizeof(struct t_overview_fmt) * (8 + 1));
@@ -400,8 +401,8 @@ art_mark_xref_read(
 					if (debug & DEBUG_NEWSRC) {
 						debug_mesg = fmt_string("FOUND!Xref: [%s:%"T_ARTNUM_PFMT"] marked READ num_unread=[%"T_ARTNUM_PFMT"]",
 							groupname, artnum, group->newsrc.num_unread);
-							debug_print_comment(debug_mesg);
-							debug_print_bitmap(group, NULL);
+						debug_print_comment(debug_mesg);
+						debug_print_bitmap(group, NULL);
 /*						error_message(2, debug_mesg); */
 						free(debug_mesg);
 					}
